# coding: utf-8

# -----------------------------------------------------------------------------------
# <copyright company="Aspose">
#   Copyright (c) 2018 Aspose.Slides for Cloud
# </copyright>
# <summary>
#   Permission is hereby granted, free of charge, to any person obtaining a copy
#  of this software and associated documentation files (the "Software"), to deal
#  in the Software without restriction, including without limitation the rights
#  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
#  copies of the Software, and to permit persons to whom the Software is
#  furnished to do so, subject to the following conditions:
#
#  The above copyright notice and this permission notice shall be included in all
#  copies or substantial portions of the Software.
#
#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
#  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
#  SOFTWARE.
# </summary>
# -----------------------------------------------------------------------------------

import pprint
import re  # noqa: F401

import six

from asposeslidescloud.models.task import Task

class UpdateBackground(Task):


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'type': 'str',
        'slides': 'list[int]',
        'background': 'SlideBackground'
    }

    attribute_map = {
        'type': 'type',
        'slides': 'slides',
        'background': 'background'
    }

    type_determiners = {
        'type': 'UpdateBackground',
    }

    def __init__(self, type='UpdateBackground', slides=None, background=None):  # noqa: E501
        """UpdateBackground - a model defined in Swagger"""  # noqa: E501
        super(UpdateBackground, self).__init__(type)

        self._slides = None
        self._background = None
        self.type: 'UpdateBackground'

        if slides is not None:
            self.slides = slides
        if background is not None:
            self.background = background

    @property
    def slides(self):
        """Gets the slides of this UpdateBackground.  # noqa: E501

        List of slide indices.  # noqa: E501

        :return: The slides of this UpdateBackground.  # noqa: E501
        :rtype: list[int]
        """
        return self._slides

    @slides.setter
    def slides(self, slides):
        """Sets the slides of this UpdateBackground.

        List of slide indices.  # noqa: E501

        :param slides: The slides of this UpdateBackground.  # noqa: E501
        :type: list[int]
        """
        self._slides = slides

    @property
    def background(self):
        """Gets the background of this UpdateBackground.  # noqa: E501

        Background DTO.  # noqa: E501

        :return: The background of this UpdateBackground.  # noqa: E501
        :rtype: SlideBackground
        """
        return self._background

    @background.setter
    def background(self, background):
        """Sets the background of this UpdateBackground.

        Background DTO.  # noqa: E501

        :param background: The background of this UpdateBackground.  # noqa: E501
        :type: SlideBackground
        """
        self._background = background

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UpdateBackground):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

# -----------------------------------------------------------------------------------
# <copyright company="Aspose">
#   Copyright (c) 2018 Aspose.Slides for Cloud
# </copyright>
# <summary>
#   Permission is hereby granted, free of charge, to any person obtaining a copy
#  of this software and associated documentation files (the "Software"), to deal
#  in the Software without restriction, including without limitation the rights
#  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
#  copies of the Software, and to permit persons to whom the Software is
#  furnished to do so, subject to the following conditions:
#
#  The above copyright notice and this permission notice shall be included in all
#  copies or substantial portions of the Software.
#
#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
#  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
#  SOFTWARE.
# </summary>
# -----------------------------------------------------------------------------------

import pprint
import re  # noqa: F401

import six


class TableCell(object):


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'text': 'str',
        'row_span': 'int',
        'col_span': 'int',
        'margin_top': 'float',
        'margin_right': 'float',
        'margin_left': 'float',
        'margin_bottom': 'float',
        'text_anchor_type': 'str',
        'text_vertical_type': 'str',
        'fill_format': 'FillFormat',
        'border_top': 'LineFormat',
        'border_right': 'LineFormat',
        'border_left': 'LineFormat',
        'border_bottom': 'LineFormat',
        'border_diagonal_up': 'LineFormat',
        'border_diagonal_down': 'LineFormat'
    }

    attribute_map = {
        'text': 'text',
        'row_span': 'rowSpan',
        'col_span': 'colSpan',
        'margin_top': 'marginTop',
        'margin_right': 'marginRight',
        'margin_left': 'marginLeft',
        'margin_bottom': 'marginBottom',
        'text_anchor_type': 'textAnchorType',
        'text_vertical_type': 'textVerticalType',
        'fill_format': 'fillFormat',
        'border_top': 'borderTop',
        'border_right': 'borderRight',
        'border_left': 'borderLeft',
        'border_bottom': 'borderBottom',
        'border_diagonal_up': 'borderDiagonalUp',
        'border_diagonal_down': 'borderDiagonalDown'
    }

    type_determiners = {
    }

    def __init__(self, text=None, row_span=None, col_span=None, margin_top=None, margin_right=None, margin_left=None, margin_bottom=None, text_anchor_type=None, text_vertical_type=None, fill_format=None, border_top=None, border_right=None, border_left=None, border_bottom=None, border_diagonal_up=None, border_diagonal_down=None):  # noqa: E501
        """TableCell - a model defined in Swagger"""  # noqa: E501

        self._text = None
        self._row_span = None
        self._col_span = None
        self._margin_top = None
        self._margin_right = None
        self._margin_left = None
        self._margin_bottom = None
        self._text_anchor_type = None
        self._text_vertical_type = None
        self._fill_format = None
        self._border_top = None
        self._border_right = None
        self._border_left = None
        self._border_bottom = None
        self._border_diagonal_up = None
        self._border_diagonal_down = None

        if text is not None:
            self.text = text
        if row_span is not None:
            self.row_span = row_span
        if col_span is not None:
            self.col_span = col_span
        if margin_top is not None:
            self.margin_top = margin_top
        if margin_right is not None:
            self.margin_right = margin_right
        if margin_left is not None:
            self.margin_left = margin_left
        if margin_bottom is not None:
            self.margin_bottom = margin_bottom
        if text_anchor_type is not None:
            self.text_anchor_type = text_anchor_type
        if text_vertical_type is not None:
            self.text_vertical_type = text_vertical_type
        if fill_format is not None:
            self.fill_format = fill_format
        if border_top is not None:
            self.border_top = border_top
        if border_right is not None:
            self.border_right = border_right
        if border_left is not None:
            self.border_left = border_left
        if border_bottom is not None:
            self.border_bottom = border_bottom
        if border_diagonal_up is not None:
            self.border_diagonal_up = border_diagonal_up
        if border_diagonal_down is not None:
            self.border_diagonal_down = border_diagonal_down

    @property
    def text(self):
        """Gets the text of this TableCell.  # noqa: E501

        Cell text.  # noqa: E501

        :return: The text of this TableCell.  # noqa: E501
        :rtype: str
        """
        return self._text

    @text.setter
    def text(self, text):
        """Sets the text of this TableCell.

        Cell text.  # noqa: E501

        :param text: The text of this TableCell.  # noqa: E501
        :type: str
        """
        self._text = text

    @property
    def row_span(self):
        """Gets the row_span of this TableCell.  # noqa: E501

        The number of rows spanned by a merged cell.  # noqa: E501

        :return: The row_span of this TableCell.  # noqa: E501
        :rtype: int
        """
        return self._row_span

    @row_span.setter
    def row_span(self, row_span):
        """Sets the row_span of this TableCell.

        The number of rows spanned by a merged cell.  # noqa: E501

        :param row_span: The row_span of this TableCell.  # noqa: E501
        :type: int
        """
        self._row_span = row_span

    @property
    def col_span(self):
        """Gets the col_span of this TableCell.  # noqa: E501

        The number of columns spanned by a merged cell.  # noqa: E501

        :return: The col_span of this TableCell.  # noqa: E501
        :rtype: int
        """
        return self._col_span

    @col_span.setter
    def col_span(self, col_span):
        """Sets the col_span of this TableCell.

        The number of columns spanned by a merged cell.  # noqa: E501

        :param col_span: The col_span of this TableCell.  # noqa: E501
        :type: int
        """
        self._col_span = col_span

    @property
    def margin_top(self):
        """Gets the margin_top of this TableCell.  # noqa: E501

        The top margin of the cell.  # noqa: E501

        :return: The margin_top of this TableCell.  # noqa: E501
        :rtype: float
        """
        return self._margin_top

    @margin_top.setter
    def margin_top(self, margin_top):
        """Sets the margin_top of this TableCell.

        The top margin of the cell.  # noqa: E501

        :param margin_top: The margin_top of this TableCell.  # noqa: E501
        :type: float
        """
        self._margin_top = margin_top

    @property
    def margin_right(self):
        """Gets the margin_right of this TableCell.  # noqa: E501

        The right margin of the cell.  # noqa: E501

        :return: The margin_right of this TableCell.  # noqa: E501
        :rtype: float
        """
        return self._margin_right

    @margin_right.setter
    def margin_right(self, margin_right):
        """Sets the margin_right of this TableCell.

        The right margin of the cell.  # noqa: E501

        :param margin_right: The margin_right of this TableCell.  # noqa: E501
        :type: float
        """
        self._margin_right = margin_right

    @property
    def margin_left(self):
        """Gets the margin_left of this TableCell.  # noqa: E501

        The left margin of the cell.  # noqa: E501

        :return: The margin_left of this TableCell.  # noqa: E501
        :rtype: float
        """
        return self._margin_left

    @margin_left.setter
    def margin_left(self, margin_left):
        """Sets the margin_left of this TableCell.

        The left margin of the cell.  # noqa: E501

        :param margin_left: The margin_left of this TableCell.  # noqa: E501
        :type: float
        """
        self._margin_left = margin_left

    @property
    def margin_bottom(self):
        """Gets the margin_bottom of this TableCell.  # noqa: E501

        The bottom margin of the cell.  # noqa: E501

        :return: The margin_bottom of this TableCell.  # noqa: E501
        :rtype: float
        """
        return self._margin_bottom

    @margin_bottom.setter
    def margin_bottom(self, margin_bottom):
        """Sets the margin_bottom of this TableCell.

        The bottom margin of the cell.  # noqa: E501

        :param margin_bottom: The margin_bottom of this TableCell.  # noqa: E501
        :type: float
        """
        self._margin_bottom = margin_bottom

    @property
    def text_anchor_type(self):
        """Gets the text_anchor_type of this TableCell.  # noqa: E501

        Text anchor type.  # noqa: E501

        :return: The text_anchor_type of this TableCell.  # noqa: E501
        :rtype: str
        """
        return self._text_anchor_type

    @text_anchor_type.setter
    def text_anchor_type(self, text_anchor_type):
        """Sets the text_anchor_type of this TableCell.

        Text anchor type.  # noqa: E501

        :param text_anchor_type: The text_anchor_type of this TableCell.  # noqa: E501
        :type: str
        """
        if text_anchor_type is not None:
            allowed_values = ["Top", "Center", "Bottom", "Justified", "Distributed", "NotDefined"]  # noqa: E501
            if text_anchor_type.isdigit():
                int_text_anchor_type = int(text_anchor_type)
                if int_text_anchor_type < 0 or int_text_anchor_type >= len(allowed_values):
                    raise ValueError(
                        "Invalid value for `text_anchor_type` ({0}), must be one of {1}"  # noqa: E501
                        .format(text_anchor_type, allowed_values)
                    )
                self._text_anchor_type = allowed_values[int_text_anchor_type]
                return
            if text_anchor_type not in allowed_values:
                raise ValueError(
                    "Invalid value for `text_anchor_type` ({0}), must be one of {1}"  # noqa: E501
                    .format(text_anchor_type, allowed_values)
                )
        self._text_anchor_type = text_anchor_type

    @property
    def text_vertical_type(self):
        """Gets the text_vertical_type of this TableCell.  # noqa: E501

        The type of vertical text.  # noqa: E501

        :return: The text_vertical_type of this TableCell.  # noqa: E501
        :rtype: str
        """
        return self._text_vertical_type

    @text_vertical_type.setter
    def text_vertical_type(self, text_vertical_type):
        """Sets the text_vertical_type of this TableCell.

        The type of vertical text.  # noqa: E501

        :param text_vertical_type: The text_vertical_type of this TableCell.  # noqa: E501
        :type: str
        """
        if text_vertical_type is not None:
            allowed_values = ["Horizontal", "Vertical", "Vertical270", "WordArtVertical", "EastAsianVertical", "MongolianVertical", "WordArtVerticalRightToLeft", "NotDefined"]  # noqa: E501
            if text_vertical_type.isdigit():
                int_text_vertical_type = int(text_vertical_type)
                if int_text_vertical_type < 0 or int_text_vertical_type >= len(allowed_values):
                    raise ValueError(
                        "Invalid value for `text_vertical_type` ({0}), must be one of {1}"  # noqa: E501
                        .format(text_vertical_type, allowed_values)
                    )
                self._text_vertical_type = allowed_values[int_text_vertical_type]
                return
            if text_vertical_type not in allowed_values:
                raise ValueError(
                    "Invalid value for `text_vertical_type` ({0}), must be one of {1}"  # noqa: E501
                    .format(text_vertical_type, allowed_values)
                )
        self._text_vertical_type = text_vertical_type

    @property
    def fill_format(self):
        """Gets the fill_format of this TableCell.  # noqa: E501

        Fill properties set of the cell.  # noqa: E501

        :return: The fill_format of this TableCell.  # noqa: E501
        :rtype: FillFormat
        """
        return self._fill_format

    @fill_format.setter
    def fill_format(self, fill_format):
        """Sets the fill_format of this TableCell.

        Fill properties set of the cell.  # noqa: E501

        :param fill_format: The fill_format of this TableCell.  # noqa: E501
        :type: FillFormat
        """
        self._fill_format = fill_format

    @property
    def border_top(self):
        """Gets the border_top of this TableCell.  # noqa: E501

        Line properties set for the top border of the cell.  # noqa: E501

        :return: The border_top of this TableCell.  # noqa: E501
        :rtype: LineFormat
        """
        return self._border_top

    @border_top.setter
    def border_top(self, border_top):
        """Sets the border_top of this TableCell.

        Line properties set for the top border of the cell.  # noqa: E501

        :param border_top: The border_top of this TableCell.  # noqa: E501
        :type: LineFormat
        """
        self._border_top = border_top

    @property
    def border_right(self):
        """Gets the border_right of this TableCell.  # noqa: E501

        Line properties set for the right border of the cell.  # noqa: E501

        :return: The border_right of this TableCell.  # noqa: E501
        :rtype: LineFormat
        """
        return self._border_right

    @border_right.setter
    def border_right(self, border_right):
        """Sets the border_right of this TableCell.

        Line properties set for the right border of the cell.  # noqa: E501

        :param border_right: The border_right of this TableCell.  # noqa: E501
        :type: LineFormat
        """
        self._border_right = border_right

    @property
    def border_left(self):
        """Gets the border_left of this TableCell.  # noqa: E501

        Line properties set for the left border of the cell.  # noqa: E501

        :return: The border_left of this TableCell.  # noqa: E501
        :rtype: LineFormat
        """
        return self._border_left

    @border_left.setter
    def border_left(self, border_left):
        """Sets the border_left of this TableCell.

        Line properties set for the left border of the cell.  # noqa: E501

        :param border_left: The border_left of this TableCell.  # noqa: E501
        :type: LineFormat
        """
        self._border_left = border_left

    @property
    def border_bottom(self):
        """Gets the border_bottom of this TableCell.  # noqa: E501

        Line properties set for the bottom border of the cell.  # noqa: E501

        :return: The border_bottom of this TableCell.  # noqa: E501
        :rtype: LineFormat
        """
        return self._border_bottom

    @border_bottom.setter
    def border_bottom(self, border_bottom):
        """Sets the border_bottom of this TableCell.

        Line properties set for the bottom border of the cell.  # noqa: E501

        :param border_bottom: The border_bottom of this TableCell.  # noqa: E501
        :type: LineFormat
        """
        self._border_bottom = border_bottom

    @property
    def border_diagonal_up(self):
        """Gets the border_diagonal_up of this TableCell.  # noqa: E501

        Line properties set for the diagonal up border of the cell.  # noqa: E501

        :return: The border_diagonal_up of this TableCell.  # noqa: E501
        :rtype: LineFormat
        """
        return self._border_diagonal_up

    @border_diagonal_up.setter
    def border_diagonal_up(self, border_diagonal_up):
        """Sets the border_diagonal_up of this TableCell.

        Line properties set for the diagonal up border of the cell.  # noqa: E501

        :param border_diagonal_up: The border_diagonal_up of this TableCell.  # noqa: E501
        :type: LineFormat
        """
        self._border_diagonal_up = border_diagonal_up

    @property
    def border_diagonal_down(self):
        """Gets the border_diagonal_down of this TableCell.  # noqa: E501

        Line properties set for the diagonal down border of the cell.  # noqa: E501

        :return: The border_diagonal_down of this TableCell.  # noqa: E501
        :rtype: LineFormat
        """
        return self._border_diagonal_down

    @border_diagonal_down.setter
    def border_diagonal_down(self, border_diagonal_down):
        """Sets the border_diagonal_down of this TableCell.

        Line properties set for the diagonal down border of the cell.  # noqa: E501

        :param border_diagonal_down: The border_diagonal_down of this TableCell.  # noqa: E501
        :type: LineFormat
        """
        self._border_diagonal_down = border_diagonal_down

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, TableCell):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

# -----------------------------------------------------------------------------------
# <copyright company="Aspose">
#   Copyright (c) 2018 Aspose.Slides for Cloud
# </copyright>
# <summary>
#   Permission is hereby granted, free of charge, to any person obtaining a copy
#  of this software and associated documentation files (the "Software"), to deal
#  in the Software without restriction, including without limitation the rights
#  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
#  copies of the Software, and to permit persons to whom the Software is
#  furnished to do so, subject to the following conditions:
#
#  The above copyright notice and this permission notice shall be included in all
#  copies or substantial portions of the Software.
#
#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
#  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
#  SOFTWARE.
# </summary>
# -----------------------------------------------------------------------------------

import pprint
import re  # noqa: F401

import six

from asposeslidescloud.models.export_options import ExportOptions

class PdfExportOptions(ExportOptions):


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'format': 'str',
        'text_compression': 'str',
        'embed_full_fonts': 'bool',
        'compliance': 'str',
        'sufficient_resolution': 'float',
        'jpeg_quality': 'int',
        'draw_slides_frame': 'bool',
        'show_hidden_slides': 'bool',
        'save_metafiles_as_png': 'bool',
        'password': 'str',
        'embed_true_type_fonts_for_ascii': 'bool',
        'additional_common_font_families': 'list[str]',
        'notes_position': 'str',
        'comments_position': 'str',
        'comments_area_width': 'int',
        'comments_area_color': 'str',
        'show_comments_by_no_author': 'bool',
        'image_transparent_color': 'str',
        'apply_image_transparent': 'bool'
    }

    attribute_map = {
        'format': 'format',
        'text_compression': 'textCompression',
        'embed_full_fonts': 'embedFullFonts',
        'compliance': 'compliance',
        'sufficient_resolution': 'sufficientResolution',
        'jpeg_quality': 'jpegQuality',
        'draw_slides_frame': 'drawSlidesFrame',
        'show_hidden_slides': 'showHiddenSlides',
        'save_metafiles_as_png': 'saveMetafilesAsPng',
        'password': 'password',
        'embed_true_type_fonts_for_ascii': 'embedTrueTypeFontsForAscii',
        'additional_common_font_families': 'additionalCommonFontFamilies',
        'notes_position': 'notesPosition',
        'comments_position': 'commentsPosition',
        'comments_area_width': 'commentsAreaWidth',
        'comments_area_color': 'commentsAreaColor',
        'show_comments_by_no_author': 'showCommentsByNoAuthor',
        'image_transparent_color': 'imageTransparentColor',
        'apply_image_transparent': 'applyImageTransparent'
    }

    type_determiners = {
        'format': 'pdf',
    }

    def __init__(self, format='pdf', text_compression=None, embed_full_fonts=None, compliance=None, sufficient_resolution=None, jpeg_quality=None, draw_slides_frame=None, show_hidden_slides=None, save_metafiles_as_png=None, password=None, embed_true_type_fonts_for_ascii=None, additional_common_font_families=None, notes_position=None, comments_position=None, comments_area_width=None, comments_area_color=None, show_comments_by_no_author=None, image_transparent_color=None, apply_image_transparent=None):  # noqa: E501
        """PdfExportOptions - a model defined in Swagger"""  # noqa: E501
        super(PdfExportOptions, self).__init__(format)

        self._text_compression = None
        self._embed_full_fonts = None
        self._compliance = None
        self._sufficient_resolution = None
        self._jpeg_quality = None
        self._draw_slides_frame = None
        self._show_hidden_slides = None
        self._save_metafiles_as_png = None
        self._password = None
        self._embed_true_type_fonts_for_ascii = None
        self._additional_common_font_families = None
        self._notes_position = None
        self._comments_position = None
        self._comments_area_width = None
        self._comments_area_color = None
        self._show_comments_by_no_author = None
        self._image_transparent_color = None
        self._apply_image_transparent = None
        self.format: 'pdf'

        self.text_compression = text_compression
        self.embed_full_fonts = embed_full_fonts
        self.compliance = compliance
        self.sufficient_resolution = sufficient_resolution
        self.jpeg_quality = jpeg_quality
        self.draw_slides_frame = draw_slides_frame
        self.show_hidden_slides = show_hidden_slides
        self.save_metafiles_as_png = save_metafiles_as_png
        if password is not None:
            self.password = password
        self.embed_true_type_fonts_for_ascii = embed_true_type_fonts_for_ascii
        if additional_common_font_families is not None:
            self.additional_common_font_families = additional_common_font_families
        self.notes_position = notes_position
        self.comments_position = comments_position
        self.comments_area_width = comments_area_width
        if comments_area_color is not None:
            self.comments_area_color = comments_area_color
        self.show_comments_by_no_author = show_comments_by_no_author
        if image_transparent_color is not None:
            self.image_transparent_color = image_transparent_color
        self.apply_image_transparent = apply_image_transparent

    @property
    def text_compression(self):
        """Gets the text_compression of this PdfExportOptions.  # noqa: E501

        Specifies compression type to be used for all textual content in the document.  # noqa: E501

        :return: The text_compression of this PdfExportOptions.  # noqa: E501
        :rtype: str
        """
        return self._text_compression

    @text_compression.setter
    def text_compression(self, text_compression):
        """Sets the text_compression of this PdfExportOptions.

        Specifies compression type to be used for all textual content in the document.  # noqa: E501

        :param text_compression: The text_compression of this PdfExportOptions.  # noqa: E501
        :type: str
        """
        if text_compression is not None:
            allowed_values = ["None", "Flate"]  # noqa: E501
            if text_compression.isdigit():
                int_text_compression = int(text_compression)
                if int_text_compression < 0 or int_text_compression >= len(allowed_values):
                    raise ValueError(
                        "Invalid value for `text_compression` ({0}), must be one of {1}"  # noqa: E501
                        .format(text_compression, allowed_values)
                    )
                self._text_compression = allowed_values[int_text_compression]
                return
            if text_compression not in allowed_values:
                raise ValueError(
                    "Invalid value for `text_compression` ({0}), must be one of {1}"  # noqa: E501
                    .format(text_compression, allowed_values)
                )
        self._text_compression = text_compression

    @property
    def embed_full_fonts(self):
        """Gets the embed_full_fonts of this PdfExportOptions.  # noqa: E501

        Determines if all characters of font should be embedded or only used subset.  # noqa: E501

        :return: The embed_full_fonts of this PdfExportOptions.  # noqa: E501
        :rtype: bool
        """
        return self._embed_full_fonts

    @embed_full_fonts.setter
    def embed_full_fonts(self, embed_full_fonts):
        """Sets the embed_full_fonts of this PdfExportOptions.

        Determines if all characters of font should be embedded or only used subset.  # noqa: E501

        :param embed_full_fonts: The embed_full_fonts of this PdfExportOptions.  # noqa: E501
        :type: bool
        """
        self._embed_full_fonts = embed_full_fonts

    @property
    def compliance(self):
        """Gets the compliance of this PdfExportOptions.  # noqa: E501

        Desired conformance level for generated PDF document.  # noqa: E501

        :return: The compliance of this PdfExportOptions.  # noqa: E501
        :rtype: str
        """
        return self._compliance

    @compliance.setter
    def compliance(self, compliance):
        """Sets the compliance of this PdfExportOptions.

        Desired conformance level for generated PDF document.  # noqa: E501

        :param compliance: The compliance of this PdfExportOptions.  # noqa: E501
        :type: str
        """
        if compliance is not None:
            allowed_values = ["Pdf15", "PdfA1b"]  # noqa: E501
            if compliance.isdigit():
                int_compliance = int(compliance)
                if int_compliance < 0 or int_compliance >= len(allowed_values):
                    raise ValueError(
                        "Invalid value for `compliance` ({0}), must be one of {1}"  # noqa: E501
                        .format(compliance, allowed_values)
                    )
                self._compliance = allowed_values[int_compliance]
                return
            if compliance not in allowed_values:
                raise ValueError(
                    "Invalid value for `compliance` ({0}), must be one of {1}"  # noqa: E501
                    .format(compliance, allowed_values)
                )
        self._compliance = compliance

    @property
    def sufficient_resolution(self):
        """Gets the sufficient_resolution of this PdfExportOptions.  # noqa: E501

        Returns or sets a value determining resolution of images inside PDF document.  Property affects on file size, time of export and image quality. The default value is 96.  # noqa: E501

        :return: The sufficient_resolution of this PdfExportOptions.  # noqa: E501
        :rtype: float
        """
        return self._sufficient_resolution

    @sufficient_resolution.setter
    def sufficient_resolution(self, sufficient_resolution):
        """Sets the sufficient_resolution of this PdfExportOptions.

        Returns or sets a value determining resolution of images inside PDF document.  Property affects on file size, time of export and image quality. The default value is 96.  # noqa: E501

        :param sufficient_resolution: The sufficient_resolution of this PdfExportOptions.  # noqa: E501
        :type: float
        """
        self._sufficient_resolution = sufficient_resolution

    @property
    def jpeg_quality(self):
        """Gets the jpeg_quality of this PdfExportOptions.  # noqa: E501

        Returns or sets a value determining the quality of the JPEG images inside PDF document.  # noqa: E501

        :return: The jpeg_quality of this PdfExportOptions.  # noqa: E501
        :rtype: int
        """
        return self._jpeg_quality

    @jpeg_quality.setter
    def jpeg_quality(self, jpeg_quality):
        """Sets the jpeg_quality of this PdfExportOptions.

        Returns or sets a value determining the quality of the JPEG images inside PDF document.  # noqa: E501

        :param jpeg_quality: The jpeg_quality of this PdfExportOptions.  # noqa: E501
        :type: int
        """
        self._jpeg_quality = jpeg_quality

    @property
    def draw_slides_frame(self):
        """Gets the draw_slides_frame of this PdfExportOptions.  # noqa: E501

        True to draw black frame around each slide.  # noqa: E501

        :return: The draw_slides_frame of this PdfExportOptions.  # noqa: E501
        :rtype: bool
        """
        return self._draw_slides_frame

    @draw_slides_frame.setter
    def draw_slides_frame(self, draw_slides_frame):
        """Sets the draw_slides_frame of this PdfExportOptions.

        True to draw black frame around each slide.  # noqa: E501

        :param draw_slides_frame: The draw_slides_frame of this PdfExportOptions.  # noqa: E501
        :type: bool
        """
        self._draw_slides_frame = draw_slides_frame

    @property
    def show_hidden_slides(self):
        """Gets the show_hidden_slides of this PdfExportOptions.  # noqa: E501

        Specifies whether the generated document should include hidden slides or not. Default is false.   # noqa: E501

        :return: The show_hidden_slides of this PdfExportOptions.  # noqa: E501
        :rtype: bool
        """
        return self._show_hidden_slides

    @show_hidden_slides.setter
    def show_hidden_slides(self, show_hidden_slides):
        """Sets the show_hidden_slides of this PdfExportOptions.

        Specifies whether the generated document should include hidden slides or not. Default is false.   # noqa: E501

        :param show_hidden_slides: The show_hidden_slides of this PdfExportOptions.  # noqa: E501
        :type: bool
        """
        self._show_hidden_slides = show_hidden_slides

    @property
    def save_metafiles_as_png(self):
        """Gets the save_metafiles_as_png of this PdfExportOptions.  # noqa: E501

        True to convert all metafiles used in a presentation to the PNG images.  # noqa: E501

        :return: The save_metafiles_as_png of this PdfExportOptions.  # noqa: E501
        :rtype: bool
        """
        return self._save_metafiles_as_png

    @save_metafiles_as_png.setter
    def save_metafiles_as_png(self, save_metafiles_as_png):
        """Sets the save_metafiles_as_png of this PdfExportOptions.

        True to convert all metafiles used in a presentation to the PNG images.  # noqa: E501

        :param save_metafiles_as_png: The save_metafiles_as_png of this PdfExportOptions.  # noqa: E501
        :type: bool
        """
        self._save_metafiles_as_png = save_metafiles_as_png

    @property
    def password(self):
        """Gets the password of this PdfExportOptions.  # noqa: E501

        Setting user password to protect the PDF document.   # noqa: E501

        :return: The password of this PdfExportOptions.  # noqa: E501
        :rtype: str
        """
        return self._password

    @password.setter
    def password(self, password):
        """Sets the password of this PdfExportOptions.

        Setting user password to protect the PDF document.   # noqa: E501

        :param password: The password of this PdfExportOptions.  # noqa: E501
        :type: str
        """
        self._password = password

    @property
    def embed_true_type_fonts_for_ascii(self):
        """Gets the embed_true_type_fonts_for_ascii of this PdfExportOptions.  # noqa: E501

        Determines if Aspose.Slides will embed common fonts for ASCII (33..127 code range) text. Fonts for character codes greater than 127 are always embedded. Common fonts list includes PDF's base 14 fonts and additional user specified fonts.  # noqa: E501

        :return: The embed_true_type_fonts_for_ascii of this PdfExportOptions.  # noqa: E501
        :rtype: bool
        """
        return self._embed_true_type_fonts_for_ascii

    @embed_true_type_fonts_for_ascii.setter
    def embed_true_type_fonts_for_ascii(self, embed_true_type_fonts_for_ascii):
        """Sets the embed_true_type_fonts_for_ascii of this PdfExportOptions.

        Determines if Aspose.Slides will embed common fonts for ASCII (33..127 code range) text. Fonts for character codes greater than 127 are always embedded. Common fonts list includes PDF's base 14 fonts and additional user specified fonts.  # noqa: E501

        :param embed_true_type_fonts_for_ascii: The embed_true_type_fonts_for_ascii of this PdfExportOptions.  # noqa: E501
        :type: bool
        """
        self._embed_true_type_fonts_for_ascii = embed_true_type_fonts_for_ascii

    @property
    def additional_common_font_families(self):
        """Gets the additional_common_font_families of this PdfExportOptions.  # noqa: E501

        Returns or sets an array of user-defined names of font families which Aspose.Slides should consider common.  # noqa: E501

        :return: The additional_common_font_families of this PdfExportOptions.  # noqa: E501
        :rtype: list[str]
        """
        return self._additional_common_font_families

    @additional_common_font_families.setter
    def additional_common_font_families(self, additional_common_font_families):
        """Sets the additional_common_font_families of this PdfExportOptions.

        Returns or sets an array of user-defined names of font families which Aspose.Slides should consider common.  # noqa: E501

        :param additional_common_font_families: The additional_common_font_families of this PdfExportOptions.  # noqa: E501
        :type: list[str]
        """
        self._additional_common_font_families = additional_common_font_families

    @property
    def notes_position(self):
        """Gets the notes_position of this PdfExportOptions.  # noqa: E501

        Gets or sets the position of the notes on the page.  # noqa: E501

        :return: The notes_position of this PdfExportOptions.  # noqa: E501
        :rtype: str
        """
        return self._notes_position

    @notes_position.setter
    def notes_position(self, notes_position):
        """Sets the notes_position of this PdfExportOptions.

        Gets or sets the position of the notes on the page.  # noqa: E501

        :param notes_position: The notes_position of this PdfExportOptions.  # noqa: E501
        :type: str
        """
        if notes_position is not None:
            allowed_values = ["None", "BottomFull", "BottomTruncated"]  # noqa: E501
            if notes_position.isdigit():
                int_notes_position = int(notes_position)
                if int_notes_position < 0 or int_notes_position >= len(allowed_values):
                    raise ValueError(
                        "Invalid value for `notes_position` ({0}), must be one of {1}"  # noqa: E501
                        .format(notes_position, allowed_values)
                    )
                self._notes_position = allowed_values[int_notes_position]
                return
            if notes_position not in allowed_values:
                raise ValueError(
                    "Invalid value for `notes_position` ({0}), must be one of {1}"  # noqa: E501
                    .format(notes_position, allowed_values)
                )
        self._notes_position = notes_position

    @property
    def comments_position(self):
        """Gets the comments_position of this PdfExportOptions.  # noqa: E501

        Gets or sets the position of the comments on the page.  # noqa: E501

        :return: The comments_position of this PdfExportOptions.  # noqa: E501
        :rtype: str
        """
        return self._comments_position

    @comments_position.setter
    def comments_position(self, comments_position):
        """Sets the comments_position of this PdfExportOptions.

        Gets or sets the position of the comments on the page.  # noqa: E501

        :param comments_position: The comments_position of this PdfExportOptions.  # noqa: E501
        :type: str
        """
        if comments_position is not None:
            allowed_values = ["None", "Bottom", "Right"]  # noqa: E501
            if comments_position.isdigit():
                int_comments_position = int(comments_position)
                if int_comments_position < 0 or int_comments_position >= len(allowed_values):
                    raise ValueError(
                        "Invalid value for `comments_position` ({0}), must be one of {1}"  # noqa: E501
                        .format(comments_position, allowed_values)
                    )
                self._comments_position = allowed_values[int_comments_position]
                return
            if comments_position not in allowed_values:
                raise ValueError(
                    "Invalid value for `comments_position` ({0}), must be one of {1}"  # noqa: E501
                    .format(comments_position, allowed_values)
                )
        self._comments_position = comments_position

    @property
    def comments_area_width(self):
        """Gets the comments_area_width of this PdfExportOptions.  # noqa: E501

        Gets or sets the width of the comment output area in pixels (Applies only if comments are displayed on the right).  # noqa: E501

        :return: The comments_area_width of this PdfExportOptions.  # noqa: E501
        :rtype: int
        """
        return self._comments_area_width

    @comments_area_width.setter
    def comments_area_width(self, comments_area_width):
        """Sets the comments_area_width of this PdfExportOptions.

        Gets or sets the width of the comment output area in pixels (Applies only if comments are displayed on the right).  # noqa: E501

        :param comments_area_width: The comments_area_width of this PdfExportOptions.  # noqa: E501
        :type: int
        """
        self._comments_area_width = comments_area_width

    @property
    def comments_area_color(self):
        """Gets the comments_area_color of this PdfExportOptions.  # noqa: E501

        Gets or sets the color of comments area (Applies only if comments are displayed on the right).  # noqa: E501

        :return: The comments_area_color of this PdfExportOptions.  # noqa: E501
        :rtype: str
        """
        return self._comments_area_color

    @comments_area_color.setter
    def comments_area_color(self, comments_area_color):
        """Sets the comments_area_color of this PdfExportOptions.

        Gets or sets the color of comments area (Applies only if comments are displayed on the right).  # noqa: E501

        :param comments_area_color: The comments_area_color of this PdfExportOptions.  # noqa: E501
        :type: str
        """
        self._comments_area_color = comments_area_color

    @property
    def show_comments_by_no_author(self):
        """Gets the show_comments_by_no_author of this PdfExportOptions.  # noqa: E501

        True if comments that have no author are displayed. (Applies only if comments are displayed).  # noqa: E501

        :return: The show_comments_by_no_author of this PdfExportOptions.  # noqa: E501
        :rtype: bool
        """
        return self._show_comments_by_no_author

    @show_comments_by_no_author.setter
    def show_comments_by_no_author(self, show_comments_by_no_author):
        """Sets the show_comments_by_no_author of this PdfExportOptions.

        True if comments that have no author are displayed. (Applies only if comments are displayed).  # noqa: E501

        :param show_comments_by_no_author: The show_comments_by_no_author of this PdfExportOptions.  # noqa: E501
        :type: bool
        """
        self._show_comments_by_no_author = show_comments_by_no_author

    @property
    def image_transparent_color(self):
        """Gets the image_transparent_color of this PdfExportOptions.  # noqa: E501

        Image transparent color.  # noqa: E501

        :return: The image_transparent_color of this PdfExportOptions.  # noqa: E501
        :rtype: str
        """
        return self._image_transparent_color

    @image_transparent_color.setter
    def image_transparent_color(self, image_transparent_color):
        """Sets the image_transparent_color of this PdfExportOptions.

        Image transparent color.  # noqa: E501

        :param image_transparent_color: The image_transparent_color of this PdfExportOptions.  # noqa: E501
        :type: str
        """
        self._image_transparent_color = image_transparent_color

    @property
    def apply_image_transparent(self):
        """Gets the apply_image_transparent of this PdfExportOptions.  # noqa: E501

        True to apply specified ImageTransparentColor  to an image.  # noqa: E501

        :return: The apply_image_transparent of this PdfExportOptions.  # noqa: E501
        :rtype: bool
        """
        return self._apply_image_transparent

    @apply_image_transparent.setter
    def apply_image_transparent(self, apply_image_transparent):
        """Sets the apply_image_transparent of this PdfExportOptions.

        True to apply specified ImageTransparentColor  to an image.  # noqa: E501

        :param apply_image_transparent: The apply_image_transparent of this PdfExportOptions.  # noqa: E501
        :type: bool
        """
        self._apply_image_transparent = apply_image_transparent

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PdfExportOptions):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

# -----------------------------------------------------------------------------------
# <copyright company="Aspose">
#   Copyright (c) 2018 Aspose.Slides for Cloud
# </copyright>
# <summary>
#   Permission is hereby granted, free of charge, to any person obtaining a copy
#  of this software and associated documentation files (the "Software"), to deal
#  in the Software without restriction, including without limitation the rights
#  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
#  copies of the Software, and to permit persons to whom the Software is
#  furnished to do so, subject to the following conditions:
#
#  The above copyright notice and this permission notice shall be included in all
#  copies or substantial portions of the Software.
#
#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
#  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
#  SOFTWARE.
# </summary>
# -----------------------------------------------------------------------------------

import pprint
import re  # noqa: F401

import six

from asposeslidescloud.models.export_options import ExportOptions

class HtmlExportOptions(ExportOptions):


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'format': 'str',
        'save_as_zip': 'bool',
        'sub_directory_name': 'str',
        'show_hidden_slides': 'bool',
        'svg_responsive_layout': 'bool',
        'jpeg_quality': 'int',
        'pictures_compression': 'str',
        'delete_pictures_cropped_areas': 'bool',
        'notes_position': 'str',
        'comments_position': 'str',
        'comments_area_width': 'int',
        'comments_area_color': 'str',
        'show_comments_by_no_author': 'bool'
    }

    attribute_map = {
        'format': 'format',
        'save_as_zip': 'saveAsZip',
        'sub_directory_name': 'subDirectoryName',
        'show_hidden_slides': 'showHiddenSlides',
        'svg_responsive_layout': 'svgResponsiveLayout',
        'jpeg_quality': 'jpegQuality',
        'pictures_compression': 'picturesCompression',
        'delete_pictures_cropped_areas': 'deletePicturesCroppedAreas',
        'notes_position': 'notesPosition',
        'comments_position': 'commentsPosition',
        'comments_area_width': 'commentsAreaWidth',
        'comments_area_color': 'commentsAreaColor',
        'show_comments_by_no_author': 'showCommentsByNoAuthor'
    }

    type_determiners = {
        'format': 'html',
    }

    def __init__(self, format='html', save_as_zip=None, sub_directory_name=None, show_hidden_slides=None, svg_responsive_layout=None, jpeg_quality=None, pictures_compression=None, delete_pictures_cropped_areas=None, notes_position=None, comments_position=None, comments_area_width=None, comments_area_color=None, show_comments_by_no_author=None):  # noqa: E501
        """HtmlExportOptions - a model defined in Swagger"""  # noqa: E501
        super(HtmlExportOptions, self).__init__(format)

        self._save_as_zip = None
        self._sub_directory_name = None
        self._show_hidden_slides = None
        self._svg_responsive_layout = None
        self._jpeg_quality = None
        self._pictures_compression = None
        self._delete_pictures_cropped_areas = None
        self._notes_position = None
        self._comments_position = None
        self._comments_area_width = None
        self._comments_area_color = None
        self._show_comments_by_no_author = None
        self.format: 'html'

        self.save_as_zip = save_as_zip
        if sub_directory_name is not None:
            self.sub_directory_name = sub_directory_name
        self.show_hidden_slides = show_hidden_slides
        self.svg_responsive_layout = svg_responsive_layout
        self.jpeg_quality = jpeg_quality
        if pictures_compression is not None:
            self.pictures_compression = pictures_compression
        self.delete_pictures_cropped_areas = delete_pictures_cropped_areas
        self.notes_position = notes_position
        self.comments_position = comments_position
        self.comments_area_width = comments_area_width
        if comments_area_color is not None:
            self.comments_area_color = comments_area_color
        self.show_comments_by_no_author = show_comments_by_no_author

    @property
    def save_as_zip(self):
        """Gets the save_as_zip of this HtmlExportOptions.  # noqa: E501

        Get or sets flag for save presentation as zip file  # noqa: E501

        :return: The save_as_zip of this HtmlExportOptions.  # noqa: E501
        :rtype: bool
        """
        return self._save_as_zip

    @save_as_zip.setter
    def save_as_zip(self, save_as_zip):
        """Sets the save_as_zip of this HtmlExportOptions.

        Get or sets flag for save presentation as zip file  # noqa: E501

        :param save_as_zip: The save_as_zip of this HtmlExportOptions.  # noqa: E501
        :type: bool
        """
        self._save_as_zip = save_as_zip

    @property
    def sub_directory_name(self):
        """Gets the sub_directory_name of this HtmlExportOptions.  # noqa: E501

        Get or set name of subdirectory in zip-file for store external files  # noqa: E501

        :return: The sub_directory_name of this HtmlExportOptions.  # noqa: E501
        :rtype: str
        """
        return self._sub_directory_name

    @sub_directory_name.setter
    def sub_directory_name(self, sub_directory_name):
        """Sets the sub_directory_name of this HtmlExportOptions.

        Get or set name of subdirectory in zip-file for store external files  # noqa: E501

        :param sub_directory_name: The sub_directory_name of this HtmlExportOptions.  # noqa: E501
        :type: str
        """
        self._sub_directory_name = sub_directory_name

    @property
    def show_hidden_slides(self):
        """Gets the show_hidden_slides of this HtmlExportOptions.  # noqa: E501

        Specifies whether the generated document should include hidden slides or not. Default is false.   # noqa: E501

        :return: The show_hidden_slides of this HtmlExportOptions.  # noqa: E501
        :rtype: bool
        """
        return self._show_hidden_slides

    @show_hidden_slides.setter
    def show_hidden_slides(self, show_hidden_slides):
        """Sets the show_hidden_slides of this HtmlExportOptions.

        Specifies whether the generated document should include hidden slides or not. Default is false.   # noqa: E501

        :param show_hidden_slides: The show_hidden_slides of this HtmlExportOptions.  # noqa: E501
        :type: bool
        """
        self._show_hidden_slides = show_hidden_slides

    @property
    def svg_responsive_layout(self):
        """Gets the svg_responsive_layout of this HtmlExportOptions.  # noqa: E501

        True to make layout responsive by excluding width and height attributes from svg container.  # noqa: E501

        :return: The svg_responsive_layout of this HtmlExportOptions.  # noqa: E501
        :rtype: bool
        """
        return self._svg_responsive_layout

    @svg_responsive_layout.setter
    def svg_responsive_layout(self, svg_responsive_layout):
        """Sets the svg_responsive_layout of this HtmlExportOptions.

        True to make layout responsive by excluding width and height attributes from svg container.  # noqa: E501

        :param svg_responsive_layout: The svg_responsive_layout of this HtmlExportOptions.  # noqa: E501
        :type: bool
        """
        self._svg_responsive_layout = svg_responsive_layout

    @property
    def jpeg_quality(self):
        """Gets the jpeg_quality of this HtmlExportOptions.  # noqa: E501

        Returns or sets a value determining the quality of the JPEG images inside PDF document.  # noqa: E501

        :return: The jpeg_quality of this HtmlExportOptions.  # noqa: E501
        :rtype: int
        """
        return self._jpeg_quality

    @jpeg_quality.setter
    def jpeg_quality(self, jpeg_quality):
        """Sets the jpeg_quality of this HtmlExportOptions.

        Returns or sets a value determining the quality of the JPEG images inside PDF document.  # noqa: E501

        :param jpeg_quality: The jpeg_quality of this HtmlExportOptions.  # noqa: E501
        :type: int
        """
        self._jpeg_quality = jpeg_quality

    @property
    def pictures_compression(self):
        """Gets the pictures_compression of this HtmlExportOptions.  # noqa: E501

        Represents the pictures compression level  # noqa: E501

        :return: The pictures_compression of this HtmlExportOptions.  # noqa: E501
        :rtype: str
        """
        return self._pictures_compression

    @pictures_compression.setter
    def pictures_compression(self, pictures_compression):
        """Sets the pictures_compression of this HtmlExportOptions.

        Represents the pictures compression level  # noqa: E501

        :param pictures_compression: The pictures_compression of this HtmlExportOptions.  # noqa: E501
        :type: str
        """
        if pictures_compression is not None:
            allowed_values = ["Dpi330", "Dpi220", "Dpi150", "Dpi96", "Dpi72", "DocumentResolution"]  # noqa: E501
            if pictures_compression.isdigit():
                int_pictures_compression = int(pictures_compression)
                if int_pictures_compression < 0 or int_pictures_compression >= len(allowed_values):
                    raise ValueError(
                        "Invalid value for `pictures_compression` ({0}), must be one of {1}"  # noqa: E501
                        .format(pictures_compression, allowed_values)
                    )
                self._pictures_compression = allowed_values[int_pictures_compression]
                return
            if pictures_compression not in allowed_values:
                raise ValueError(
                    "Invalid value for `pictures_compression` ({0}), must be one of {1}"  # noqa: E501
                    .format(pictures_compression, allowed_values)
                )
        self._pictures_compression = pictures_compression

    @property
    def delete_pictures_cropped_areas(self):
        """Gets the delete_pictures_cropped_areas of this HtmlExportOptions.  # noqa: E501

        A boolean flag indicates if the cropped parts remain as part of the document. If true the cropped  parts will removed, if false they will be serialized in the document (which can possible lead to a  larger file)  # noqa: E501

        :return: The delete_pictures_cropped_areas of this HtmlExportOptions.  # noqa: E501
        :rtype: bool
        """
        return self._delete_pictures_cropped_areas

    @delete_pictures_cropped_areas.setter
    def delete_pictures_cropped_areas(self, delete_pictures_cropped_areas):
        """Sets the delete_pictures_cropped_areas of this HtmlExportOptions.

        A boolean flag indicates if the cropped parts remain as part of the document. If true the cropped  parts will removed, if false they will be serialized in the document (which can possible lead to a  larger file)  # noqa: E501

        :param delete_pictures_cropped_areas: The delete_pictures_cropped_areas of this HtmlExportOptions.  # noqa: E501
        :type: bool
        """
        self._delete_pictures_cropped_areas = delete_pictures_cropped_areas

    @property
    def notes_position(self):
        """Gets the notes_position of this HtmlExportOptions.  # noqa: E501

        Gets or sets the position of the notes on the page.  # noqa: E501

        :return: The notes_position of this HtmlExportOptions.  # noqa: E501
        :rtype: str
        """
        return self._notes_position

    @notes_position.setter
    def notes_position(self, notes_position):
        """Sets the notes_position of this HtmlExportOptions.

        Gets or sets the position of the notes on the page.  # noqa: E501

        :param notes_position: The notes_position of this HtmlExportOptions.  # noqa: E501
        :type: str
        """
        if notes_position is not None:
            allowed_values = ["None", "BottomFull", "BottomTruncated"]  # noqa: E501
            if notes_position.isdigit():
                int_notes_position = int(notes_position)
                if int_notes_position < 0 or int_notes_position >= len(allowed_values):
                    raise ValueError(
                        "Invalid value for `notes_position` ({0}), must be one of {1}"  # noqa: E501
                        .format(notes_position, allowed_values)
                    )
                self._notes_position = allowed_values[int_notes_position]
                return
            if notes_position not in allowed_values:
                raise ValueError(
                    "Invalid value for `notes_position` ({0}), must be one of {1}"  # noqa: E501
                    .format(notes_position, allowed_values)
                )
        self._notes_position = notes_position

    @property
    def comments_position(self):
        """Gets the comments_position of this HtmlExportOptions.  # noqa: E501

        Gets or sets the position of the comments on the page.  # noqa: E501

        :return: The comments_position of this HtmlExportOptions.  # noqa: E501
        :rtype: str
        """
        return self._comments_position

    @comments_position.setter
    def comments_position(self, comments_position):
        """Sets the comments_position of this HtmlExportOptions.

        Gets or sets the position of the comments on the page.  # noqa: E501

        :param comments_position: The comments_position of this HtmlExportOptions.  # noqa: E501
        :type: str
        """
        if comments_position is not None:
            allowed_values = ["None", "Bottom", "Right"]  # noqa: E501
            if comments_position.isdigit():
                int_comments_position = int(comments_position)
                if int_comments_position < 0 or int_comments_position >= len(allowed_values):
                    raise ValueError(
                        "Invalid value for `comments_position` ({0}), must be one of {1}"  # noqa: E501
                        .format(comments_position, allowed_values)
                    )
                self._comments_position = allowed_values[int_comments_position]
                return
            if comments_position not in allowed_values:
                raise ValueError(
                    "Invalid value for `comments_position` ({0}), must be one of {1}"  # noqa: E501
                    .format(comments_position, allowed_values)
                )
        self._comments_position = comments_position

    @property
    def comments_area_width(self):
        """Gets the comments_area_width of this HtmlExportOptions.  # noqa: E501

        Gets or sets the width of the comment output area in pixels (Applies only if comments are displayed on the right).  # noqa: E501

        :return: The comments_area_width of this HtmlExportOptions.  # noqa: E501
        :rtype: int
        """
        return self._comments_area_width

    @comments_area_width.setter
    def comments_area_width(self, comments_area_width):
        """Sets the comments_area_width of this HtmlExportOptions.

        Gets or sets the width of the comment output area in pixels (Applies only if comments are displayed on the right).  # noqa: E501

        :param comments_area_width: The comments_area_width of this HtmlExportOptions.  # noqa: E501
        :type: int
        """
        self._comments_area_width = comments_area_width

    @property
    def comments_area_color(self):
        """Gets the comments_area_color of this HtmlExportOptions.  # noqa: E501

        Gets or sets the color of comments area (Applies only if comments are displayed on the right).  # noqa: E501

        :return: The comments_area_color of this HtmlExportOptions.  # noqa: E501
        :rtype: str
        """
        return self._comments_area_color

    @comments_area_color.setter
    def comments_area_color(self, comments_area_color):
        """Sets the comments_area_color of this HtmlExportOptions.

        Gets or sets the color of comments area (Applies only if comments are displayed on the right).  # noqa: E501

        :param comments_area_color: The comments_area_color of this HtmlExportOptions.  # noqa: E501
        :type: str
        """
        self._comments_area_color = comments_area_color

    @property
    def show_comments_by_no_author(self):
        """Gets the show_comments_by_no_author of this HtmlExportOptions.  # noqa: E501

        True if comments that have no author are displayed. (Applies only if comments are displayed).  # noqa: E501

        :return: The show_comments_by_no_author of this HtmlExportOptions.  # noqa: E501
        :rtype: bool
        """
        return self._show_comments_by_no_author

    @show_comments_by_no_author.setter
    def show_comments_by_no_author(self, show_comments_by_no_author):
        """Sets the show_comments_by_no_author of this HtmlExportOptions.

        True if comments that have no author are displayed. (Applies only if comments are displayed).  # noqa: E501

        :param show_comments_by_no_author: The show_comments_by_no_author of this HtmlExportOptions.  # noqa: E501
        :type: bool
        """
        self._show_comments_by_no_author = show_comments_by_no_author

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, HtmlExportOptions):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

# -----------------------------------------------------------------------------------
# <copyright company="Aspose">
#   Copyright (c) 2018 Aspose.Slides for Cloud
# </copyright>
# <summary>
#   Permission is hereby granted, free of charge, to any person obtaining a copy
#  of this software and associated documentation files (the "Software"), to deal
#  in the Software without restriction, including without limitation the rights
#  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
#  copies of the Software, and to permit persons to whom the Software is
#  furnished to do so, subject to the following conditions:
#
#  The above copyright notice and this permission notice shall be included in all
#  copies or substantial portions of the Software.
#
#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
#  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
#  SOFTWARE.
# </summary>
# -----------------------------------------------------------------------------------

import pprint
import re  # noqa: F401

import six

from asposeslidescloud.models.resource_base import ResourceBase

class ViewProperties(ResourceBase):


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'self_uri': 'ResourceUri',
        'alternate_links': 'list[ResourceUri]',
        'last_view': 'str',
        'horizontal_bar_state': 'str',
        'vertical_bar_state': 'str',
        'prefer_single_view': 'bool',
        'restored_left': 'NormalViewRestoredProperties',
        'restored_top': 'NormalViewRestoredProperties',
        'slide_view_properties': 'CommonSlideViewProperties',
        'notes_view_properties': 'CommonSlideViewProperties',
        'show_comments': 'str'
    }

    attribute_map = {
        'self_uri': 'selfUri',
        'alternate_links': 'alternateLinks',
        'last_view': 'lastView',
        'horizontal_bar_state': 'horizontalBarState',
        'vertical_bar_state': 'verticalBarState',
        'prefer_single_view': 'preferSingleView',
        'restored_left': 'restoredLeft',
        'restored_top': 'restoredTop',
        'slide_view_properties': 'slideViewProperties',
        'notes_view_properties': 'notesViewProperties',
        'show_comments': 'showComments'
    }

    type_determiners = {
    }

    def __init__(self, self_uri=None, alternate_links=None, last_view=None, horizontal_bar_state=None, vertical_bar_state=None, prefer_single_view=None, restored_left=None, restored_top=None, slide_view_properties=None, notes_view_properties=None, show_comments=None):  # noqa: E501
        """ViewProperties - a model defined in Swagger"""  # noqa: E501
        super(ViewProperties, self).__init__(self_uri, alternate_links)

        self._last_view = None
        self._horizontal_bar_state = None
        self._vertical_bar_state = None
        self._prefer_single_view = None
        self._restored_left = None
        self._restored_top = None
        self._slide_view_properties = None
        self._notes_view_properties = None
        self._show_comments = None

        if last_view is not None:
            self.last_view = last_view
        if horizontal_bar_state is not None:
            self.horizontal_bar_state = horizontal_bar_state
        if vertical_bar_state is not None:
            self.vertical_bar_state = vertical_bar_state
        if prefer_single_view is not None:
            self.prefer_single_view = prefer_single_view
        if restored_left is not None:
            self.restored_left = restored_left
        if restored_top is not None:
            self.restored_top = restored_top
        if slide_view_properties is not None:
            self.slide_view_properties = slide_view_properties
        if notes_view_properties is not None:
            self.notes_view_properties = notes_view_properties
        if show_comments is not None:
            self.show_comments = show_comments

    @property
    def last_view(self):
        """Gets the last_view of this ViewProperties.  # noqa: E501

        Last used view mode.  # noqa: E501

        :return: The last_view of this ViewProperties.  # noqa: E501
        :rtype: str
        """
        return self._last_view

    @last_view.setter
    def last_view(self, last_view):
        """Sets the last_view of this ViewProperties.

        Last used view mode.  # noqa: E501

        :param last_view: The last_view of this ViewProperties.  # noqa: E501
        :type: str
        """
        if last_view is not None:
            allowed_values = ["NotDefined", "SlideView", "SlideMasterView", "NotesView", "HandoutView", "NotesMasterView", "OutlineView", "SlideSorterView", "SlideThumbnailView"]  # noqa: E501
            if last_view.isdigit():
                int_last_view = int(last_view)
                if int_last_view < 0 or int_last_view >= len(allowed_values):
                    raise ValueError(
                        "Invalid value for `last_view` ({0}), must be one of {1}"  # noqa: E501
                        .format(last_view, allowed_values)
                    )
                self._last_view = allowed_values[int_last_view]
                return
            if last_view not in allowed_values:
                raise ValueError(
                    "Invalid value for `last_view` ({0}), must be one of {1}"  # noqa: E501
                    .format(last_view, allowed_values)
                )
        self._last_view = last_view

    @property
    def horizontal_bar_state(self):
        """Gets the horizontal_bar_state of this ViewProperties.  # noqa: E501

        Horizontal bar state.  # noqa: E501

        :return: The horizontal_bar_state of this ViewProperties.  # noqa: E501
        :rtype: str
        """
        return self._horizontal_bar_state

    @horizontal_bar_state.setter
    def horizontal_bar_state(self, horizontal_bar_state):
        """Sets the horizontal_bar_state of this ViewProperties.

        Horizontal bar state.  # noqa: E501

        :param horizontal_bar_state: The horizontal_bar_state of this ViewProperties.  # noqa: E501
        :type: str
        """
        if horizontal_bar_state is not None:
            allowed_values = ["Minimized", "Restored", "Maximized"]  # noqa: E501
            if horizontal_bar_state.isdigit():
                int_horizontal_bar_state = int(horizontal_bar_state)
                if int_horizontal_bar_state < 0 or int_horizontal_bar_state >= len(allowed_values):
                    raise ValueError(
                        "Invalid value for `horizontal_bar_state` ({0}), must be one of {1}"  # noqa: E501
                        .format(horizontal_bar_state, allowed_values)
                    )
                self._horizontal_bar_state = allowed_values[int_horizontal_bar_state]
                return
            if horizontal_bar_state not in allowed_values:
                raise ValueError(
                    "Invalid value for `horizontal_bar_state` ({0}), must be one of {1}"  # noqa: E501
                    .format(horizontal_bar_state, allowed_values)
                )
        self._horizontal_bar_state = horizontal_bar_state

    @property
    def vertical_bar_state(self):
        """Gets the vertical_bar_state of this ViewProperties.  # noqa: E501

        Vertical bar state.  # noqa: E501

        :return: The vertical_bar_state of this ViewProperties.  # noqa: E501
        :rtype: str
        """
        return self._vertical_bar_state

    @vertical_bar_state.setter
    def vertical_bar_state(self, vertical_bar_state):
        """Sets the vertical_bar_state of this ViewProperties.

        Vertical bar state.  # noqa: E501

        :param vertical_bar_state: The vertical_bar_state of this ViewProperties.  # noqa: E501
        :type: str
        """
        if vertical_bar_state is not None:
            allowed_values = ["Minimized", "Restored", "Maximized"]  # noqa: E501
            if vertical_bar_state.isdigit():
                int_vertical_bar_state = int(vertical_bar_state)
                if int_vertical_bar_state < 0 or int_vertical_bar_state >= len(allowed_values):
                    raise ValueError(
                        "Invalid value for `vertical_bar_state` ({0}), must be one of {1}"  # noqa: E501
                        .format(vertical_bar_state, allowed_values)
                    )
                self._vertical_bar_state = allowed_values[int_vertical_bar_state]
                return
            if vertical_bar_state not in allowed_values:
                raise ValueError(
                    "Invalid value for `vertical_bar_state` ({0}), must be one of {1}"  # noqa: E501
                    .format(vertical_bar_state, allowed_values)
                )
        self._vertical_bar_state = vertical_bar_state

    @property
    def prefer_single_view(self):
        """Gets the prefer_single_view of this ViewProperties.  # noqa: E501

        True to prefer single view.  # noqa: E501

        :return: The prefer_single_view of this ViewProperties.  # noqa: E501
        :rtype: bool
        """
        return self._prefer_single_view

    @prefer_single_view.setter
    def prefer_single_view(self, prefer_single_view):
        """Sets the prefer_single_view of this ViewProperties.

        True to prefer single view.  # noqa: E501

        :param prefer_single_view: The prefer_single_view of this ViewProperties.  # noqa: E501
        :type: bool
        """
        self._prefer_single_view = prefer_single_view

    @property
    def restored_left(self):
        """Gets the restored_left of this ViewProperties.  # noqa: E501

        The sizing of the side content region of the normal view, when the region is of a variable restored size.  # noqa: E501

        :return: The restored_left of this ViewProperties.  # noqa: E501
        :rtype: NormalViewRestoredProperties
        """
        return self._restored_left

    @restored_left.setter
    def restored_left(self, restored_left):
        """Sets the restored_left of this ViewProperties.

        The sizing of the side content region of the normal view, when the region is of a variable restored size.  # noqa: E501

        :param restored_left: The restored_left of this ViewProperties.  # noqa: E501
        :type: NormalViewRestoredProperties
        """
        self._restored_left = restored_left

    @property
    def restored_top(self):
        """Gets the restored_top of this ViewProperties.  # noqa: E501

        The sizing of the top slide region of the normal view, when the region is of a variable restored size.  # noqa: E501

        :return: The restored_top of this ViewProperties.  # noqa: E501
        :rtype: NormalViewRestoredProperties
        """
        return self._restored_top

    @restored_top.setter
    def restored_top(self, restored_top):
        """Sets the restored_top of this ViewProperties.

        The sizing of the top slide region of the normal view, when the region is of a variable restored size.  # noqa: E501

        :param restored_top: The restored_top of this ViewProperties.  # noqa: E501
        :type: NormalViewRestoredProperties
        """
        self._restored_top = restored_top

    @property
    def slide_view_properties(self):
        """Gets the slide_view_properties of this ViewProperties.  # noqa: E501

        Slide view mode properties.  # noqa: E501

        :return: The slide_view_properties of this ViewProperties.  # noqa: E501
        :rtype: CommonSlideViewProperties
        """
        return self._slide_view_properties

    @slide_view_properties.setter
    def slide_view_properties(self, slide_view_properties):
        """Sets the slide_view_properties of this ViewProperties.

        Slide view mode properties.  # noqa: E501

        :param slide_view_properties: The slide_view_properties of this ViewProperties.  # noqa: E501
        :type: CommonSlideViewProperties
        """
        self._slide_view_properties = slide_view_properties

    @property
    def notes_view_properties(self):
        """Gets the notes_view_properties of this ViewProperties.  # noqa: E501

        Notes view mode properties.  # noqa: E501

        :return: The notes_view_properties of this ViewProperties.  # noqa: E501
        :rtype: CommonSlideViewProperties
        """
        return self._notes_view_properties

    @notes_view_properties.setter
    def notes_view_properties(self, notes_view_properties):
        """Sets the notes_view_properties of this ViewProperties.

        Notes view mode properties.  # noqa: E501

        :param notes_view_properties: The notes_view_properties of this ViewProperties.  # noqa: E501
        :type: CommonSlideViewProperties
        """
        self._notes_view_properties = notes_view_properties

    @property
    def show_comments(self):
        """Gets the show_comments of this ViewProperties.  # noqa: E501

        True if the comments should be shown.  # noqa: E501

        :return: The show_comments of this ViewProperties.  # noqa: E501
        :rtype: str
        """
        return self._show_comments

    @show_comments.setter
    def show_comments(self, show_comments):
        """Sets the show_comments of this ViewProperties.

        True if the comments should be shown.  # noqa: E501

        :param show_comments: The show_comments of this ViewProperties.  # noqa: E501
        :type: str
        """
        if show_comments is not None:
            allowed_values = ["False", "True", "NotDefined"]  # noqa: E501
            if show_comments.isdigit():
                int_show_comments = int(show_comments)
                if int_show_comments < 0 or int_show_comments >= len(allowed_values):
                    raise ValueError(
                        "Invalid value for `show_comments` ({0}), must be one of {1}"  # noqa: E501
                        .format(show_comments, allowed_values)
                    )
                self._show_comments = allowed_values[int_show_comments]
                return
            if show_comments not in allowed_values:
                raise ValueError(
                    "Invalid value for `show_comments` ({0}), must be one of {1}"  # noqa: E501
                    .format(show_comments, allowed_values)
                )
        self._show_comments = show_comments

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ViewProperties):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name="asposeslidescloud",
    version="20.4.0",
    author="Victor Putrov",
    author_email="vistor.putrov@aspose.com",
    description="Aspose.Slides Cloud SDK for Python",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="",
    packages=setuptools.find_packages(),
    install_requires=[ "urllib3 >= 1.15.1", "six >= 1.10", "certifi >= 14.05.14" ],
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent"
    ]
)


# coding: utf-8

# -----------------------------------------------------------------------------------
# <copyright company="Aspose">
#   Copyright (c) 2018 Aspose.Slides for Cloud
# </copyright>
# <summary>
#   Permission is hereby granted, free of charge, to any person obtaining a copy
#  of this software and associated documentation files (the "Software"), to deal
#  in the Software without restriction, including without limitation the rights
#  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
#  copies of the Software, and to permit persons to whom the Software is
#  furnished to do so, subject to the following conditions:
#
#  The above copyright notice and this permission notice shall be included in all
#  copies or substantial portions of the Software.
#
#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
#  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
#  SOFTWARE.
# </summary>
# -----------------------------------------------------------------------------------

import pprint
import re  # noqa: F401

import six

from asposeslidescloud.models.resource_base import ResourceBase

class SlideBackground(ResourceBase):


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'self_uri': 'ResourceUri',
        'alternate_links': 'list[ResourceUri]',
        'type': 'str',
        'fill_format': 'FillFormat',
        'effect_format': 'EffectFormat'
    }

    attribute_map = {
        'self_uri': 'selfUri',
        'alternate_links': 'alternateLinks',
        'type': 'type',
        'fill_format': 'fillFormat',
        'effect_format': 'effectFormat'
    }

    type_determiners = {
    }

    def __init__(self, self_uri=None, alternate_links=None, type=None, fill_format=None, effect_format=None):  # noqa: E501
        """SlideBackground - a model defined in Swagger"""  # noqa: E501
        super(SlideBackground, self).__init__(self_uri, alternate_links)

        self._type = None
        self._fill_format = None
        self._effect_format = None

        self.type = type
        if fill_format is not None:
            self.fill_format = fill_format
        if effect_format is not None:
            self.effect_format = effect_format

    @property
    def type(self):
        """Gets the type of this SlideBackground.  # noqa: E501

        Fill type.  # noqa: E501

        :return: The type of this SlideBackground.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this SlideBackground.

        Fill type.  # noqa: E501

        :param type: The type of this SlideBackground.  # noqa: E501
        :type: str
        """
        if type is not None:
            allowed_values = ["NoFill", "Solid", "Gradient", "Pattern", "Picture", "NotDefined"]  # noqa: E501
            if type.isdigit():
                int_type = int(type)
                if int_type < 0 or int_type >= len(allowed_values):
                    raise ValueError(
                        "Invalid value for `type` ({0}), must be one of {1}"  # noqa: E501
                        .format(type, allowed_values)
                    )
                self._type = allowed_values[int_type]
                return
            if type not in allowed_values:
                raise ValueError(
                    "Invalid value for `type` ({0}), must be one of {1}"  # noqa: E501
                    .format(type, allowed_values)
                )
        self._type = type

    @property
    def fill_format(self):
        """Gets the fill_format of this SlideBackground.  # noqa: E501

        Fill format.  # noqa: E501

        :return: The fill_format of this SlideBackground.  # noqa: E501
        :rtype: FillFormat
        """
        return self._fill_format

    @fill_format.setter
    def fill_format(self, fill_format):
        """Sets the fill_format of this SlideBackground.

        Fill format.  # noqa: E501

        :param fill_format: The fill_format of this SlideBackground.  # noqa: E501
        :type: FillFormat
        """
        self._fill_format = fill_format

    @property
    def effect_format(self):
        """Gets the effect_format of this SlideBackground.  # noqa: E501

        Effect format.  # noqa: E501

        :return: The effect_format of this SlideBackground.  # noqa: E501
        :rtype: EffectFormat
        """
        return self._effect_format

    @effect_format.setter
    def effect_format(self, effect_format):
        """Sets the effect_format of this SlideBackground.

        Effect format.  # noqa: E501

        :param effect_format: The effect_format of this SlideBackground.  # noqa: E501
        :type: EffectFormat
        """
        self._effect_format = effect_format

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SlideBackground):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

# -----------------------------------------------------------------------------------
# <copyright company="Aspose">
#   Copyright (c) 2018 Aspose.Slides for Cloud
# </copyright>
# <summary>
#   Permission is hereby granted, free of charge, to any person obtaining a copy
#  of this software and associated documentation files (the "Software"), to deal
#  in the Software without restriction, including without limitation the rights
#  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
#  copies of the Software, and to permit persons to whom the Software is
#  furnished to do so, subject to the following conditions:
#
#  The above copyright notice and this permission notice shall be included in all
#  copies or substantial portions of the Software.
#
#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
#  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
#  SOFTWARE.
# </summary>
# -----------------------------------------------------------------------------------

import pprint
import re  # noqa: F401

import six

from asposeslidescloud.models.resource_base import ResourceBase

class ColorScheme(ResourceBase):


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'self_uri': 'ResourceUri',
        'alternate_links': 'list[ResourceUri]',
        'accent1': 'str',
        'accent2': 'str',
        'accent3': 'str',
        'accent4': 'str',
        'accent5': 'str',
        'accent6': 'str',
        'dark1': 'str',
        'dark2': 'str',
        'followed_hyperlink': 'str',
        'hyperlink': 'str',
        'light1': 'str',
        'light2': 'str'
    }

    attribute_map = {
        'self_uri': 'selfUri',
        'alternate_links': 'alternateLinks',
        'accent1': 'accent1',
        'accent2': 'accent2',
        'accent3': 'accent3',
        'accent4': 'accent4',
        'accent5': 'accent5',
        'accent6': 'accent6',
        'dark1': 'dark1',
        'dark2': 'dark2',
        'followed_hyperlink': 'followedHyperlink',
        'hyperlink': 'hyperlink',
        'light1': 'light1',
        'light2': 'light2'
    }

    type_determiners = {
    }

    def __init__(self, self_uri=None, alternate_links=None, accent1=None, accent2=None, accent3=None, accent4=None, accent5=None, accent6=None, dark1=None, dark2=None, followed_hyperlink=None, hyperlink=None, light1=None, light2=None):  # noqa: E501
        """ColorScheme - a model defined in Swagger"""  # noqa: E501
        super(ColorScheme, self).__init__(self_uri, alternate_links)

        self._accent1 = None
        self._accent2 = None
        self._accent3 = None
        self._accent4 = None
        self._accent5 = None
        self._accent6 = None
        self._dark1 = None
        self._dark2 = None
        self._followed_hyperlink = None
        self._hyperlink = None
        self._light1 = None
        self._light2 = None

        if accent1 is not None:
            self.accent1 = accent1
        if accent2 is not None:
            self.accent2 = accent2
        if accent3 is not None:
            self.accent3 = accent3
        if accent4 is not None:
            self.accent4 = accent4
        if accent5 is not None:
            self.accent5 = accent5
        if accent6 is not None:
            self.accent6 = accent6
        if dark1 is not None:
            self.dark1 = dark1
        if dark2 is not None:
            self.dark2 = dark2
        if followed_hyperlink is not None:
            self.followed_hyperlink = followed_hyperlink
        if hyperlink is not None:
            self.hyperlink = hyperlink
        if light1 is not None:
            self.light1 = light1
        if light2 is not None:
            self.light2 = light2

    @property
    def accent1(self):
        """Gets the accent1 of this ColorScheme.  # noqa: E501

        First accent color.  # noqa: E501

        :return: The accent1 of this ColorScheme.  # noqa: E501
        :rtype: str
        """
        return self._accent1

    @accent1.setter
    def accent1(self, accent1):
        """Sets the accent1 of this ColorScheme.

        First accent color.  # noqa: E501

        :param accent1: The accent1 of this ColorScheme.  # noqa: E501
        :type: str
        """
        self._accent1 = accent1

    @property
    def accent2(self):
        """Gets the accent2 of this ColorScheme.  # noqa: E501

        Second accent color.  # noqa: E501

        :return: The accent2 of this ColorScheme.  # noqa: E501
        :rtype: str
        """
        return self._accent2

    @accent2.setter
    def accent2(self, accent2):
        """Sets the accent2 of this ColorScheme.

        Second accent color.  # noqa: E501

        :param accent2: The accent2 of this ColorScheme.  # noqa: E501
        :type: str
        """
        self._accent2 = accent2

    @property
    def accent3(self):
        """Gets the accent3 of this ColorScheme.  # noqa: E501

        Third accent color.  # noqa: E501

        :return: The accent3 of this ColorScheme.  # noqa: E501
        :rtype: str
        """
        return self._accent3

    @accent3.setter
    def accent3(self, accent3):
        """Sets the accent3 of this ColorScheme.

        Third accent color.  # noqa: E501

        :param accent3: The accent3 of this ColorScheme.  # noqa: E501
        :type: str
        """
        self._accent3 = accent3

    @property
    def accent4(self):
        """Gets the accent4 of this ColorScheme.  # noqa: E501

        Fourth accent color.  # noqa: E501

        :return: The accent4 of this ColorScheme.  # noqa: E501
        :rtype: str
        """
        return self._accent4

    @accent4.setter
    def accent4(self, accent4):
        """Sets the accent4 of this ColorScheme.

        Fourth accent color.  # noqa: E501

        :param accent4: The accent4 of this ColorScheme.  # noqa: E501
        :type: str
        """
        self._accent4 = accent4

    @property
    def accent5(self):
        """Gets the accent5 of this ColorScheme.  # noqa: E501

        Fifth accent color.  # noqa: E501

        :return: The accent5 of this ColorScheme.  # noqa: E501
        :rtype: str
        """
        return self._accent5

    @accent5.setter
    def accent5(self, accent5):
        """Sets the accent5 of this ColorScheme.

        Fifth accent color.  # noqa: E501

        :param accent5: The accent5 of this ColorScheme.  # noqa: E501
        :type: str
        """
        self._accent5 = accent5

    @property
    def accent6(self):
        """Gets the accent6 of this ColorScheme.  # noqa: E501

        Sixth accent color.  # noqa: E501

        :return: The accent6 of this ColorScheme.  # noqa: E501
        :rtype: str
        """
        return self._accent6

    @accent6.setter
    def accent6(self, accent6):
        """Sets the accent6 of this ColorScheme.

        Sixth accent color.  # noqa: E501

        :param accent6: The accent6 of this ColorScheme.  # noqa: E501
        :type: str
        """
        self._accent6 = accent6

    @property
    def dark1(self):
        """Gets the dark1 of this ColorScheme.  # noqa: E501

        First dark color.  # noqa: E501

        :return: The dark1 of this ColorScheme.  # noqa: E501
        :rtype: str
        """
        return self._dark1

    @dark1.setter
    def dark1(self, dark1):
        """Sets the dark1 of this ColorScheme.

        First dark color.  # noqa: E501

        :param dark1: The dark1 of this ColorScheme.  # noqa: E501
        :type: str
        """
        self._dark1 = dark1

    @property
    def dark2(self):
        """Gets the dark2 of this ColorScheme.  # noqa: E501

        Second dark color.  # noqa: E501

        :return: The dark2 of this ColorScheme.  # noqa: E501
        :rtype: str
        """
        return self._dark2

    @dark2.setter
    def dark2(self, dark2):
        """Sets the dark2 of this ColorScheme.

        Second dark color.  # noqa: E501

        :param dark2: The dark2 of this ColorScheme.  # noqa: E501
        :type: str
        """
        self._dark2 = dark2

    @property
    def followed_hyperlink(self):
        """Gets the followed_hyperlink of this ColorScheme.  # noqa: E501

        Visited hyperlink color.  # noqa: E501

        :return: The followed_hyperlink of this ColorScheme.  # noqa: E501
        :rtype: str
        """
        return self._followed_hyperlink

    @followed_hyperlink.setter
    def followed_hyperlink(self, followed_hyperlink):
        """Sets the followed_hyperlink of this ColorScheme.

        Visited hyperlink color.  # noqa: E501

        :param followed_hyperlink: The followed_hyperlink of this ColorScheme.  # noqa: E501
        :type: str
        """
        self._followed_hyperlink = followed_hyperlink

    @property
    def hyperlink(self):
        """Gets the hyperlink of this ColorScheme.  # noqa: E501

        Hyperlink color/  # noqa: E501

        :return: The hyperlink of this ColorScheme.  # noqa: E501
        :rtype: str
        """
        return self._hyperlink

    @hyperlink.setter
    def hyperlink(self, hyperlink):
        """Sets the hyperlink of this ColorScheme.

        Hyperlink color/  # noqa: E501

        :param hyperlink: The hyperlink of this ColorScheme.  # noqa: E501
        :type: str
        """
        self._hyperlink = hyperlink

    @property
    def light1(self):
        """Gets the light1 of this ColorScheme.  # noqa: E501

        First light color.  # noqa: E501

        :return: The light1 of this ColorScheme.  # noqa: E501
        :rtype: str
        """
        return self._light1

    @light1.setter
    def light1(self, light1):
        """Sets the light1 of this ColorScheme.

        First light color.  # noqa: E501

        :param light1: The light1 of this ColorScheme.  # noqa: E501
        :type: str
        """
        self._light1 = light1

    @property
    def light2(self):
        """Gets the light2 of this ColorScheme.  # noqa: E501

        Second light color.  # noqa: E501

        :return: The light2 of this ColorScheme.  # noqa: E501
        :rtype: str
        """
        return self._light2

    @light2.setter
    def light2(self, light2):
        """Sets the light2 of this ColorScheme.

        Second light color.  # noqa: E501

        :param light2: The light2 of this ColorScheme.  # noqa: E501
        :type: str
        """
        self._light2 = light2

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ColorScheme):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

# -----------------------------------------------------------------------------------
# <copyright company="Aspose">
#   Copyright (c) 2018 Aspose.Slides for Cloud
# </copyright>
# <summary>
#   Permission is hereby granted, free of charge, to any person obtaining a copy
#  of this software and associated documentation files (the "Software"), to deal
#  in the Software without restriction, including without limitation the rights
#  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
#  copies of the Software, and to permit persons to whom the Software is
#  furnished to do so, subject to the following conditions:
#
#  The above copyright notice and this permission notice shall be included in all
#  copies or substantial portions of the Software.
#
#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
#  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
#  SOFTWARE.
# </summary>
# -----------------------------------------------------------------------------------

import pprint
import re  # noqa: F401

import six


class LineFormat(object):


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'alignment': 'str',
        'cap_style': 'str',
        'dash_style': 'str',
        'join_style': 'str',
        'style': 'str',
        'begin_arrow_head': 'ArrowHeadProperties',
        'end_arrow_head': 'ArrowHeadProperties',
        'custom_dash_pattern': 'CustomDashPattern',
        'fill_format': 'FillFormat',
        'miter_limit': 'float',
        'width': 'float'
    }

    attribute_map = {
        'alignment': 'alignment',
        'cap_style': 'capStyle',
        'dash_style': 'dashStyle',
        'join_style': 'joinStyle',
        'style': 'style',
        'begin_arrow_head': 'beginArrowHead',
        'end_arrow_head': 'endArrowHead',
        'custom_dash_pattern': 'customDashPattern',
        'fill_format': 'fillFormat',
        'miter_limit': 'miterLimit',
        'width': 'width'
    }

    type_determiners = {
    }

    def __init__(self, alignment=None, cap_style=None, dash_style=None, join_style=None, style=None, begin_arrow_head=None, end_arrow_head=None, custom_dash_pattern=None, fill_format=None, miter_limit=None, width=None):  # noqa: E501
        """LineFormat - a model defined in Swagger"""  # noqa: E501

        self._alignment = None
        self._cap_style = None
        self._dash_style = None
        self._join_style = None
        self._style = None
        self._begin_arrow_head = None
        self._end_arrow_head = None
        self._custom_dash_pattern = None
        self._fill_format = None
        self._miter_limit = None
        self._width = None

        if alignment is not None:
            self.alignment = alignment
        if cap_style is not None:
            self.cap_style = cap_style
        if dash_style is not None:
            self.dash_style = dash_style
        if join_style is not None:
            self.join_style = join_style
        if style is not None:
            self.style = style
        if begin_arrow_head is not None:
            self.begin_arrow_head = begin_arrow_head
        if end_arrow_head is not None:
            self.end_arrow_head = end_arrow_head
        if custom_dash_pattern is not None:
            self.custom_dash_pattern = custom_dash_pattern
        if fill_format is not None:
            self.fill_format = fill_format
        if miter_limit is not None:
            self.miter_limit = miter_limit
        if width is not None:
            self.width = width

    @property
    def alignment(self):
        """Gets the alignment of this LineFormat.  # noqa: E501

        Alignment.  # noqa: E501

        :return: The alignment of this LineFormat.  # noqa: E501
        :rtype: str
        """
        return self._alignment

    @alignment.setter
    def alignment(self, alignment):
        """Sets the alignment of this LineFormat.

        Alignment.  # noqa: E501

        :param alignment: The alignment of this LineFormat.  # noqa: E501
        :type: str
        """
        if alignment is not None:
            allowed_values = ["Center", "Inset", "NotDefined"]  # noqa: E501
            if alignment.isdigit():
                int_alignment = int(alignment)
                if int_alignment < 0 or int_alignment >= len(allowed_values):
                    raise ValueError(
                        "Invalid value for `alignment` ({0}), must be one of {1}"  # noqa: E501
                        .format(alignment, allowed_values)
                    )
                self._alignment = allowed_values[int_alignment]
                return
            if alignment not in allowed_values:
                raise ValueError(
                    "Invalid value for `alignment` ({0}), must be one of {1}"  # noqa: E501
                    .format(alignment, allowed_values)
                )
        self._alignment = alignment

    @property
    def cap_style(self):
        """Gets the cap_style of this LineFormat.  # noqa: E501

        Cap style.  # noqa: E501

        :return: The cap_style of this LineFormat.  # noqa: E501
        :rtype: str
        """
        return self._cap_style

    @cap_style.setter
    def cap_style(self, cap_style):
        """Sets the cap_style of this LineFormat.

        Cap style.  # noqa: E501

        :param cap_style: The cap_style of this LineFormat.  # noqa: E501
        :type: str
        """
        if cap_style is not None:
            allowed_values = ["Round", "Square", "Flat", "NotDefined"]  # noqa: E501
            if cap_style.isdigit():
                int_cap_style = int(cap_style)
                if int_cap_style < 0 or int_cap_style >= len(allowed_values):
                    raise ValueError(
                        "Invalid value for `cap_style` ({0}), must be one of {1}"  # noqa: E501
                        .format(cap_style, allowed_values)
                    )
                self._cap_style = allowed_values[int_cap_style]
                return
            if cap_style not in allowed_values:
                raise ValueError(
                    "Invalid value for `cap_style` ({0}), must be one of {1}"  # noqa: E501
                    .format(cap_style, allowed_values)
                )
        self._cap_style = cap_style

    @property
    def dash_style(self):
        """Gets the dash_style of this LineFormat.  # noqa: E501

        Dash style.  # noqa: E501

        :return: The dash_style of this LineFormat.  # noqa: E501
        :rtype: str
        """
        return self._dash_style

    @dash_style.setter
    def dash_style(self, dash_style):
        """Sets the dash_style of this LineFormat.

        Dash style.  # noqa: E501

        :param dash_style: The dash_style of this LineFormat.  # noqa: E501
        :type: str
        """
        if dash_style is not None:
            allowed_values = ["Solid", "Dot", "Dash", "LargeDash", "DashDot", "LargeDashDot", "LargeDashDotDot", "SystemDash", "SystemDot", "SystemDashDot", "SystemDashDotDot", "Custom", "NotDefined"]  # noqa: E501
            if dash_style.isdigit():
                int_dash_style = int(dash_style)
                if int_dash_style < 0 or int_dash_style >= len(allowed_values):
                    raise ValueError(
                        "Invalid value for `dash_style` ({0}), must be one of {1}"  # noqa: E501
                        .format(dash_style, allowed_values)
                    )
                self._dash_style = allowed_values[int_dash_style]
                return
            if dash_style not in allowed_values:
                raise ValueError(
                    "Invalid value for `dash_style` ({0}), must be one of {1}"  # noqa: E501
                    .format(dash_style, allowed_values)
                )
        self._dash_style = dash_style

    @property
    def join_style(self):
        """Gets the join_style of this LineFormat.  # noqa: E501

        Join style.  # noqa: E501

        :return: The join_style of this LineFormat.  # noqa: E501
        :rtype: str
        """
        return self._join_style

    @join_style.setter
    def join_style(self, join_style):
        """Sets the join_style of this LineFormat.

        Join style.  # noqa: E501

        :param join_style: The join_style of this LineFormat.  # noqa: E501
        :type: str
        """
        if join_style is not None:
            allowed_values = ["Round", "Bevel", "Miter", "NotDefined"]  # noqa: E501
            if join_style.isdigit():
                int_join_style = int(join_style)
                if int_join_style < 0 or int_join_style >= len(allowed_values):
                    raise ValueError(
                        "Invalid value for `join_style` ({0}), must be one of {1}"  # noqa: E501
                        .format(join_style, allowed_values)
                    )
                self._join_style = allowed_values[int_join_style]
                return
            if join_style not in allowed_values:
                raise ValueError(
                    "Invalid value for `join_style` ({0}), must be one of {1}"  # noqa: E501
                    .format(join_style, allowed_values)
                )
        self._join_style = join_style

    @property
    def style(self):
        """Gets the style of this LineFormat.  # noqa: E501

        Style.  # noqa: E501

        :return: The style of this LineFormat.  # noqa: E501
        :rtype: str
        """
        return self._style

    @style.setter
    def style(self, style):
        """Sets the style of this LineFormat.

        Style.  # noqa: E501

        :param style: The style of this LineFormat.  # noqa: E501
        :type: str
        """
        if style is not None:
            allowed_values = ["Single", "ThinThin", "ThinThick", "ThickThin", "ThickBetweenThin", "NotDefined"]  # noqa: E501
            if style.isdigit():
                int_style = int(style)
                if int_style < 0 or int_style >= len(allowed_values):
                    raise ValueError(
                        "Invalid value for `style` ({0}), must be one of {1}"  # noqa: E501
                        .format(style, allowed_values)
                    )
                self._style = allowed_values[int_style]
                return
            if style not in allowed_values:
                raise ValueError(
                    "Invalid value for `style` ({0}), must be one of {1}"  # noqa: E501
                    .format(style, allowed_values)
                )
        self._style = style

    @property
    def begin_arrow_head(self):
        """Gets the begin_arrow_head of this LineFormat.  # noqa: E501

        Begin arrowhead.  # noqa: E501

        :return: The begin_arrow_head of this LineFormat.  # noqa: E501
        :rtype: ArrowHeadProperties
        """
        return self._begin_arrow_head

    @begin_arrow_head.setter
    def begin_arrow_head(self, begin_arrow_head):
        """Sets the begin_arrow_head of this LineFormat.

        Begin arrowhead.  # noqa: E501

        :param begin_arrow_head: The begin_arrow_head of this LineFormat.  # noqa: E501
        :type: ArrowHeadProperties
        """
        self._begin_arrow_head = begin_arrow_head

    @property
    def end_arrow_head(self):
        """Gets the end_arrow_head of this LineFormat.  # noqa: E501

        End arrowhead.  # noqa: E501

        :return: The end_arrow_head of this LineFormat.  # noqa: E501
        :rtype: ArrowHeadProperties
        """
        return self._end_arrow_head

    @end_arrow_head.setter
    def end_arrow_head(self, end_arrow_head):
        """Sets the end_arrow_head of this LineFormat.

        End arrowhead.  # noqa: E501

        :param end_arrow_head: The end_arrow_head of this LineFormat.  # noqa: E501
        :type: ArrowHeadProperties
        """
        self._end_arrow_head = end_arrow_head

    @property
    def custom_dash_pattern(self):
        """Gets the custom_dash_pattern of this LineFormat.  # noqa: E501

        Custom dash pattern.  # noqa: E501

        :return: The custom_dash_pattern of this LineFormat.  # noqa: E501
        :rtype: CustomDashPattern
        """
        return self._custom_dash_pattern

    @custom_dash_pattern.setter
    def custom_dash_pattern(self, custom_dash_pattern):
        """Sets the custom_dash_pattern of this LineFormat.

        Custom dash pattern.  # noqa: E501

        :param custom_dash_pattern: The custom_dash_pattern of this LineFormat.  # noqa: E501
        :type: CustomDashPattern
        """
        self._custom_dash_pattern = custom_dash_pattern

    @property
    def fill_format(self):
        """Gets the fill_format of this LineFormat.  # noqa: E501

        Fill format.  # noqa: E501

        :return: The fill_format of this LineFormat.  # noqa: E501
        :rtype: FillFormat
        """
        return self._fill_format

    @fill_format.setter
    def fill_format(self, fill_format):
        """Sets the fill_format of this LineFormat.

        Fill format.  # noqa: E501

        :param fill_format: The fill_format of this LineFormat.  # noqa: E501
        :type: FillFormat
        """
        self._fill_format = fill_format

    @property
    def miter_limit(self):
        """Gets the miter_limit of this LineFormat.  # noqa: E501

        Miter limit.  # noqa: E501

        :return: The miter_limit of this LineFormat.  # noqa: E501
        :rtype: float
        """
        return self._miter_limit

    @miter_limit.setter
    def miter_limit(self, miter_limit):
        """Sets the miter_limit of this LineFormat.

        Miter limit.  # noqa: E501

        :param miter_limit: The miter_limit of this LineFormat.  # noqa: E501
        :type: float
        """
        self._miter_limit = miter_limit

    @property
    def width(self):
        """Gets the width of this LineFormat.  # noqa: E501

        Width.  # noqa: E501

        :return: The width of this LineFormat.  # noqa: E501
        :rtype: float
        """
        return self._width

    @width.setter
    def width(self, width):
        """Sets the width of this LineFormat.

        Width.  # noqa: E501

        :param width: The width of this LineFormat.  # noqa: E501
        :type: float
        """
        self._width = width

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, LineFormat):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

# -----------------------------------------------------------------------------------
# <copyright company="Aspose">
#   Copyright (c) 2018 Aspose.Slides for Cloud
# </copyright>
# <summary>
#   Permission is hereby granted, free of charge, to any person obtaining a copy
#  of this software and associated documentation files (the "Software"), to deal
#  in the Software without restriction, including without limitation the rights
#  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
#  copies of the Software, and to permit persons to whom the Software is
#  furnished to do so, subject to the following conditions:
#
#  The above copyright notice and this permission notice shall be included in all
#  copies or substantial portions of the Software.
#
#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
#  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
#  SOFTWARE.
# </summary>
# -----------------------------------------------------------------------------------

import pprint
import re  # noqa: F401

import six

from asposeslidescloud.models.export_options import ExportOptions

class XpsExportOptions(ExportOptions):


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'format': 'str',
        'show_hidden_slides': 'bool',
        'save_metafiles_as_png': 'bool',
        'draw_slides_frame': 'bool'
    }

    attribute_map = {
        'format': 'format',
        'show_hidden_slides': 'showHiddenSlides',
        'save_metafiles_as_png': 'saveMetafilesAsPng',
        'draw_slides_frame': 'drawSlidesFrame'
    }

    type_determiners = {
        'format': 'xps',
    }

    def __init__(self, format='xps', show_hidden_slides=None, save_metafiles_as_png=None, draw_slides_frame=None):  # noqa: E501
        """XpsExportOptions - a model defined in Swagger"""  # noqa: E501
        super(XpsExportOptions, self).__init__(format)

        self._show_hidden_slides = None
        self._save_metafiles_as_png = None
        self._draw_slides_frame = None
        self.format: 'xps'

        self.show_hidden_slides = show_hidden_slides
        self.save_metafiles_as_png = save_metafiles_as_png
        self.draw_slides_frame = draw_slides_frame

    @property
    def show_hidden_slides(self):
        """Gets the show_hidden_slides of this XpsExportOptions.  # noqa: E501

        Specifies whether the generated document should include hidden slides or not. Default is false.   # noqa: E501

        :return: The show_hidden_slides of this XpsExportOptions.  # noqa: E501
        :rtype: bool
        """
        return self._show_hidden_slides

    @show_hidden_slides.setter
    def show_hidden_slides(self, show_hidden_slides):
        """Sets the show_hidden_slides of this XpsExportOptions.

        Specifies whether the generated document should include hidden slides or not. Default is false.   # noqa: E501

        :param show_hidden_slides: The show_hidden_slides of this XpsExportOptions.  # noqa: E501
        :type: bool
        """
        self._show_hidden_slides = show_hidden_slides

    @property
    def save_metafiles_as_png(self):
        """Gets the save_metafiles_as_png of this XpsExportOptions.  # noqa: E501

        True to convert all metafiles used in a presentation to the PNG images.  # noqa: E501

        :return: The save_metafiles_as_png of this XpsExportOptions.  # noqa: E501
        :rtype: bool
        """
        return self._save_metafiles_as_png

    @save_metafiles_as_png.setter
    def save_metafiles_as_png(self, save_metafiles_as_png):
        """Sets the save_metafiles_as_png of this XpsExportOptions.

        True to convert all metafiles used in a presentation to the PNG images.  # noqa: E501

        :param save_metafiles_as_png: The save_metafiles_as_png of this XpsExportOptions.  # noqa: E501
        :type: bool
        """
        self._save_metafiles_as_png = save_metafiles_as_png

    @property
    def draw_slides_frame(self):
        """Gets the draw_slides_frame of this XpsExportOptions.  # noqa: E501

        True to draw black frame around each slide.  # noqa: E501

        :return: The draw_slides_frame of this XpsExportOptions.  # noqa: E501
        :rtype: bool
        """
        return self._draw_slides_frame

    @draw_slides_frame.setter
    def draw_slides_frame(self, draw_slides_frame):
        """Sets the draw_slides_frame of this XpsExportOptions.

        True to draw black frame around each slide.  # noqa: E501

        :param draw_slides_frame: The draw_slides_frame of this XpsExportOptions.  # noqa: E501
        :type: bool
        """
        self._draw_slides_frame = draw_slides_frame

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, XpsExportOptions):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

# -----------------------------------------------------------------------------------
# <copyright company="Aspose">
#   Copyright (c) 2018 Aspose.Slides for Cloud
# </copyright>
# <summary>
#   Permission is hereby granted, free of charge, to any person obtaining a copy
#  of this software and associated documentation files (the "Software"), to deal
#  in the Software without restriction, including without limitation the rights
#  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
#  copies of the Software, and to permit persons to whom the Software is
#  furnished to do so, subject to the following conditions:
#
#  The above copyright notice and this permission notice shall be included in all
#  copies or substantial portions of the Software.
#
#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
#  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
#  SOFTWARE.
# </summary>
# -----------------------------------------------------------------------------------

import pprint
import re  # noqa: F401

import six

from asposeslidescloud.models.fill_format import FillFormat

class GradientFill(FillFormat):


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'type': 'str',
        'direction': 'str',
        'shape': 'str',
        'stops': 'list[GradientFillStop]',
        'linear_angle': 'float',
        'is_scaled': 'bool',
        'tile_flip': 'str'
    }

    attribute_map = {
        'type': 'type',
        'direction': 'direction',
        'shape': 'shape',
        'stops': 'stops',
        'linear_angle': 'linearAngle',
        'is_scaled': 'isScaled',
        'tile_flip': 'tileFlip'
    }

    type_determiners = {
        'type': 'Gradient',
    }

    def __init__(self, type='Gradient', direction=None, shape=None, stops=None, linear_angle=None, is_scaled=None, tile_flip=None):  # noqa: E501
        """GradientFill - a model defined in Swagger"""  # noqa: E501
        super(GradientFill, self).__init__(type)

        self._direction = None
        self._shape = None
        self._stops = None
        self._linear_angle = None
        self._is_scaled = None
        self._tile_flip = None
        self.type: 'Gradient'

        self.direction = direction
        self.shape = shape
        if stops is not None:
            self.stops = stops
        self.linear_angle = linear_angle
        self.is_scaled = is_scaled
        self.tile_flip = tile_flip

    @property
    def direction(self):
        """Gets the direction of this GradientFill.  # noqa: E501

        Gradient style.  # noqa: E501

        :return: The direction of this GradientFill.  # noqa: E501
        :rtype: str
        """
        return self._direction

    @direction.setter
    def direction(self, direction):
        """Sets the direction of this GradientFill.

        Gradient style.  # noqa: E501

        :param direction: The direction of this GradientFill.  # noqa: E501
        :type: str
        """
        if direction is not None:
            allowed_values = ["FromCorner1", "FromCorner2", "FromCorner3", "FromCorner4", "FromCenter", "NotDefined"]  # noqa: E501
            if direction.isdigit():
                int_direction = int(direction)
                if int_direction < 0 or int_direction >= len(allowed_values):
                    raise ValueError(
                        "Invalid value for `direction` ({0}), must be one of {1}"  # noqa: E501
                        .format(direction, allowed_values)
                    )
                self._direction = allowed_values[int_direction]
                return
            if direction not in allowed_values:
                raise ValueError(
                    "Invalid value for `direction` ({0}), must be one of {1}"  # noqa: E501
                    .format(direction, allowed_values)
                )
        self._direction = direction

    @property
    def shape(self):
        """Gets the shape of this GradientFill.  # noqa: E501

        Gradient shape.  # noqa: E501

        :return: The shape of this GradientFill.  # noqa: E501
        :rtype: str
        """
        return self._shape

    @shape.setter
    def shape(self, shape):
        """Sets the shape of this GradientFill.

        Gradient shape.  # noqa: E501

        :param shape: The shape of this GradientFill.  # noqa: E501
        :type: str
        """
        if shape is not None:
            allowed_values = ["Linear", "Rectangle", "Radial", "Path", "NotDefined"]  # noqa: E501
            if shape.isdigit():
                int_shape = int(shape)
                if int_shape < 0 or int_shape >= len(allowed_values):
                    raise ValueError(
                        "Invalid value for `shape` ({0}), must be one of {1}"  # noqa: E501
                        .format(shape, allowed_values)
                    )
                self._shape = allowed_values[int_shape]
                return
            if shape not in allowed_values:
                raise ValueError(
                    "Invalid value for `shape` ({0}), must be one of {1}"  # noqa: E501
                    .format(shape, allowed_values)
                )
        self._shape = shape

    @property
    def stops(self):
        """Gets the stops of this GradientFill.  # noqa: E501

        Gradient stops.  # noqa: E501

        :return: The stops of this GradientFill.  # noqa: E501
        :rtype: list[GradientFillStop]
        """
        return self._stops

    @stops.setter
    def stops(self, stops):
        """Sets the stops of this GradientFill.

        Gradient stops.  # noqa: E501

        :param stops: The stops of this GradientFill.  # noqa: E501
        :type: list[GradientFillStop]
        """
        self._stops = stops

    @property
    def linear_angle(self):
        """Gets the linear_angle of this GradientFill.  # noqa: E501

        Gradient angle.  # noqa: E501

        :return: The linear_angle of this GradientFill.  # noqa: E501
        :rtype: float
        """
        return self._linear_angle

    @linear_angle.setter
    def linear_angle(self, linear_angle):
        """Sets the linear_angle of this GradientFill.

        Gradient angle.  # noqa: E501

        :param linear_angle: The linear_angle of this GradientFill.  # noqa: E501
        :type: float
        """
        self._linear_angle = linear_angle

    @property
    def is_scaled(self):
        """Gets the is_scaled of this GradientFill.  # noqa: E501

        True if the gradient is scaled.  # noqa: E501

        :return: The is_scaled of this GradientFill.  # noqa: E501
        :rtype: bool
        """
        return self._is_scaled

    @is_scaled.setter
    def is_scaled(self, is_scaled):
        """Sets the is_scaled of this GradientFill.

        True if the gradient is scaled.  # noqa: E501

        :param is_scaled: The is_scaled of this GradientFill.  # noqa: E501
        :type: bool
        """
        self._is_scaled = is_scaled

    @property
    def tile_flip(self):
        """Gets the tile_flip of this GradientFill.  # noqa: E501

        Gradient flipping mode.  # noqa: E501

        :return: The tile_flip of this GradientFill.  # noqa: E501
        :rtype: str
        """
        return self._tile_flip

    @tile_flip.setter
    def tile_flip(self, tile_flip):
        """Sets the tile_flip of this GradientFill.

        Gradient flipping mode.  # noqa: E501

        :param tile_flip: The tile_flip of this GradientFill.  # noqa: E501
        :type: str
        """
        if tile_flip is not None:
            allowed_values = ["NoFlip", "FlipX", "FlipY", "FlipBoth", "NotDefined"]  # noqa: E501
            if tile_flip.isdigit():
                int_tile_flip = int(tile_flip)
                if int_tile_flip < 0 or int_tile_flip >= len(allowed_values):
                    raise ValueError(
                        "Invalid value for `tile_flip` ({0}), must be one of {1}"  # noqa: E501
                        .format(tile_flip, allowed_values)
                    )
                self._tile_flip = allowed_values[int_tile_flip]
                return
            if tile_flip not in allowed_values:
                raise ValueError(
                    "Invalid value for `tile_flip` ({0}), must be one of {1}"  # noqa: E501
                    .format(tile_flip, allowed_values)
                )
        self._tile_flip = tile_flip

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, GradientFill):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

# -----------------------------------------------------------------------------------
# <copyright company="Aspose">
#   Copyright (c) 2018 Aspose.Slides for Cloud
# </copyright>
# <summary>
#   Permission is hereby granted, free of charge, to any person obtaining a copy
#  of this software and associated documentation files (the "Software"), to deal
#  in the Software without restriction, including without limitation the rights
#  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
#  copies of the Software, and to permit persons to whom the Software is
#  furnished to do so, subject to the following conditions:
#
#  The above copyright notice and this permission notice shall be included in all
#  copies or substantial portions of the Software.
#
#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
#  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
#  SOFTWARE.
# </summary>
# -----------------------------------------------------------------------------------

import pprint
import re  # noqa: F401

import six


class PlotArea(object):


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'x': 'float',
        'y': 'float',
        'width': 'float',
        'height': 'float',
        'layout_target_type': 'str',
        'fill_format': 'FillFormat',
        'effect_format': 'EffectFormat',
        'line_format': 'LineFormat'
    }

    attribute_map = {
        'x': 'x',
        'y': 'y',
        'width': 'width',
        'height': 'height',
        'layout_target_type': 'layoutTargetType',
        'fill_format': 'fillFormat',
        'effect_format': 'effectFormat',
        'line_format': 'lineFormat'
    }

    type_determiners = {
    }

    def __init__(self, x=None, y=None, width=None, height=None, layout_target_type=None, fill_format=None, effect_format=None, line_format=None):  # noqa: E501
        """PlotArea - a model defined in Swagger"""  # noqa: E501

        self._x = None
        self._y = None
        self._width = None
        self._height = None
        self._layout_target_type = None
        self._fill_format = None
        self._effect_format = None
        self._line_format = None

        if x is not None:
            self.x = x
        if y is not None:
            self.y = y
        if width is not None:
            self.width = width
        if height is not None:
            self.height = height
        if layout_target_type is not None:
            self.layout_target_type = layout_target_type
        if fill_format is not None:
            self.fill_format = fill_format
        if effect_format is not None:
            self.effect_format = effect_format
        if line_format is not None:
            self.line_format = line_format

    @property
    def x(self):
        """Gets the x of this PlotArea.  # noqa: E501

        the X location  # noqa: E501

        :return: The x of this PlotArea.  # noqa: E501
        :rtype: float
        """
        return self._x

    @x.setter
    def x(self, x):
        """Sets the x of this PlotArea.

        the X location  # noqa: E501

        :param x: The x of this PlotArea.  # noqa: E501
        :type: float
        """
        self._x = x

    @property
    def y(self):
        """Gets the y of this PlotArea.  # noqa: E501

        the Y location  # noqa: E501

        :return: The y of this PlotArea.  # noqa: E501
        :rtype: float
        """
        return self._y

    @y.setter
    def y(self, y):
        """Sets the y of this PlotArea.

        the Y location  # noqa: E501

        :param y: The y of this PlotArea.  # noqa: E501
        :type: float
        """
        self._y = y

    @property
    def width(self):
        """Gets the width of this PlotArea.  # noqa: E501

        Width  # noqa: E501

        :return: The width of this PlotArea.  # noqa: E501
        :rtype: float
        """
        return self._width

    @width.setter
    def width(self, width):
        """Sets the width of this PlotArea.

        Width  # noqa: E501

        :param width: The width of this PlotArea.  # noqa: E501
        :type: float
        """
        self._width = width

    @property
    def height(self):
        """Gets the height of this PlotArea.  # noqa: E501

        Height  # noqa: E501

        :return: The height of this PlotArea.  # noqa: E501
        :rtype: float
        """
        return self._height

    @height.setter
    def height(self, height):
        """Sets the height of this PlotArea.

        Height  # noqa: E501

        :param height: The height of this PlotArea.  # noqa: E501
        :type: float
        """
        self._height = height

    @property
    def layout_target_type(self):
        """Gets the layout_target_type of this PlotArea.  # noqa: E501

        If layout of the plot area is defined manually specifies whether to layout the plot area by its inside (not including axis and axis labels) or outside.  # noqa: E501

        :return: The layout_target_type of this PlotArea.  # noqa: E501
        :rtype: str
        """
        return self._layout_target_type

    @layout_target_type.setter
    def layout_target_type(self, layout_target_type):
        """Sets the layout_target_type of this PlotArea.

        If layout of the plot area is defined manually specifies whether to layout the plot area by its inside (not including axis and axis labels) or outside.  # noqa: E501

        :param layout_target_type: The layout_target_type of this PlotArea.  # noqa: E501
        :type: str
        """
        if layout_target_type is not None:
            allowed_values = ["Inner", "Outer"]  # noqa: E501
            if layout_target_type.isdigit():
                int_layout_target_type = int(layout_target_type)
                if int_layout_target_type < 0 or int_layout_target_type >= len(allowed_values):
                    raise ValueError(
                        "Invalid value for `layout_target_type` ({0}), must be one of {1}"  # noqa: E501
                        .format(layout_target_type, allowed_values)
                    )
                self._layout_target_type = allowed_values[int_layout_target_type]
                return
            if layout_target_type not in allowed_values:
                raise ValueError(
                    "Invalid value for `layout_target_type` ({0}), must be one of {1}"  # noqa: E501
                    .format(layout_target_type, allowed_values)
                )
        self._layout_target_type = layout_target_type

    @property
    def fill_format(self):
        """Gets the fill_format of this PlotArea.  # noqa: E501

        Get or sets the fill format.  # noqa: E501

        :return: The fill_format of this PlotArea.  # noqa: E501
        :rtype: FillFormat
        """
        return self._fill_format

    @fill_format.setter
    def fill_format(self, fill_format):
        """Sets the fill_format of this PlotArea.

        Get or sets the fill format.  # noqa: E501

        :param fill_format: The fill_format of this PlotArea.  # noqa: E501
        :type: FillFormat
        """
        self._fill_format = fill_format

    @property
    def effect_format(self):
        """Gets the effect_format of this PlotArea.  # noqa: E501

        Get or sets the effect format.  # noqa: E501

        :return: The effect_format of this PlotArea.  # noqa: E501
        :rtype: EffectFormat
        """
        return self._effect_format

    @effect_format.setter
    def effect_format(self, effect_format):
        """Sets the effect_format of this PlotArea.

        Get or sets the effect format.  # noqa: E501

        :param effect_format: The effect_format of this PlotArea.  # noqa: E501
        :type: EffectFormat
        """
        self._effect_format = effect_format

    @property
    def line_format(self):
        """Gets the line_format of this PlotArea.  # noqa: E501

        Get or sets the line format.  # noqa: E501

        :return: The line_format of this PlotArea.  # noqa: E501
        :rtype: LineFormat
        """
        return self._line_format

    @line_format.setter
    def line_format(self, line_format):
        """Sets the line_format of this PlotArea.

        Get or sets the line format.  # noqa: E501

        :param line_format: The line_format of this PlotArea.  # noqa: E501
        :type: LineFormat
        """
        self._line_format = line_format

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PlotArea):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
